# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: data-node/api/v2/trading_data.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import httpbody_pb2 as google_dot_api_dot_httpbody__pb2
from protoc_gen_openapiv2.options import (
    annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2,
)
from ....vega import assets_pb2 as vega_dot_assets__pb2
from ....vega.commands.v1 import (
    validator_commands_pb2 as vega_dot_commands_dot_v1_dot_validator__commands__pb2,
)
from ....vega.events.v1 import events_pb2 as vega_dot_events_dot_v1_dot_events__pb2
from ....vega import governance_pb2 as vega_dot_governance__pb2
from ....vega import markets_pb2 as vega_dot_markets__pb2
from ....vega import oracle_pb2 as vega_dot_oracle__pb2
from ....vega import vega_pb2 as vega_dot_vega__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n#data-node/api/v2/trading_data.proto\x12\x0f\x64\x61tanode.api.v2\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/httpbody.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\x1a\x11vega/assets.proto\x1a)vega/commands/v1/validator_commands.proto\x1a\x1bvega/events/v1/events.proto\x1a\x15vega/governance.proto\x1a\x12vega/markets.proto\x1a\x11vega/oracle.proto\x1a\x0fvega/vega.proto"\xd9\x01\n\nPagination\x12\x19\n\x05\x66irst\x18\x01 \x01(\x05H\x00R\x05\x66irst\x88\x01\x01\x12\x19\n\x05\x61\x66ter\x18\x02 \x01(\tH\x01R\x05\x61\x66ter\x88\x01\x01\x12\x17\n\x04last\x18\x03 \x01(\x05H\x02R\x04last\x88\x01\x01\x12\x1b\n\x06\x62\x65\x66ore\x18\x04 \x01(\tH\x03R\x06\x62\x65\x66ore\x88\x01\x01\x12&\n\x0cnewest_first\x18\x05 \x01(\x08H\x04R\x0bnewestFirst\x88\x01\x01\x42\x08\n\x06_firstB\x08\n\x06_afterB\x07\n\x05_lastB\t\n\x07_beforeB\x0f\n\r_newest_first"\x9c\x01\n\x08PageInfo\x12"\n\rhas_next_page\x18\x01 \x01(\x08R\x0bhasNextPage\x12*\n\x11has_previous_page\x18\x02 \x01(\x08R\x0fhasPreviousPage\x12!\n\x0cstart_cursor\x18\x03 \x01(\tR\x0bstartCursor\x12\x1d\n\nend_cursor\x18\x04 \x01(\tR\tendCursor"\x9a\x01\n\x0e\x41\x63\x63ountBalance\x12\x14\n\x05owner\x18\x02 \x01(\tR\x05owner\x12\x18\n\x07\x62\x61lance\x18\x03 \x01(\tR\x07\x62\x61lance\x12\x14\n\x05\x61sset\x18\x04 \x01(\tR\x05\x61sset\x12\x1b\n\tmarket_id\x18\x05 \x01(\tR\x08marketId\x12%\n\x04type\x18\x06 \x01(\x0e\x32\x11.vega.AccountTypeR\x04type"\x9e\x01\n\x13ListAccountsRequest\x12\x36\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x1e.datanode.api.v2.AccountFilterR\x06\x66ilter\x12@\n\npagination\x18\x02 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x00R\npagination\x88\x01\x01\x42\r\n\x0b_pagination"W\n\x14ListAccountsResponse\x12?\n\x08\x61\x63\x63ounts\x18\x01 \x01(\x0b\x32#.datanode.api.v2.AccountsConnectionR\x08\x61\x63\x63ounts"\x80\x01\n\x12\x41\x63\x63ountsConnection\x12\x32\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x1c.datanode.api.v2.AccountEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"Z\n\x0b\x41\x63\x63ountEdge\x12\x33\n\x04node\x18\x01 \x01(\x0b\x32\x1f.datanode.api.v2.AccountBalanceR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x8d\x01\n\x16ObserveAccountsRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x19\n\x08party_id\x18\x02 \x01(\tR\x07partyId\x12\x14\n\x05\x61sset\x18\x03 \x01(\tR\x05\x61sset\x12%\n\x04type\x18\x04 \x01(\x0e\x32\x11.vega.AccountTypeR\x04type"\xa6\x01\n\x17ObserveAccountsResponse\x12\x42\n\x08snapshot\x18\x01 \x01(\x0b\x32$.datanode.api.v2.AccountSnapshotPageH\x00R\x08snapshot\x12;\n\x07updates\x18\x02 \x01(\x0b\x32\x1f.datanode.api.v2.AccountUpdatesH\x00R\x07updatesB\n\n\x08response"o\n\x13\x41\x63\x63ountSnapshotPage\x12;\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32\x1f.datanode.api.v2.AccountBalanceR\x08\x61\x63\x63ounts\x12\x1b\n\tlast_page\x18\x02 \x01(\x08R\x08lastPage"M\n\x0e\x41\x63\x63ountUpdates\x12;\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32\x1f.datanode.api.v2.AccountBalanceR\x08\x61\x63\x63ounts"\r\n\x0bInfoRequest"I\n\x0cInfoResponse\x12\x18\n\x07version\x18\x01 \x01(\tR\x07version\x12\x1f\n\x0b\x63ommit_hash\x18\x02 \x01(\tR\ncommitHash"]\n\x0fGetOrderRequest\x12\x1f\n\x08order_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x07orderId\x12\x1d\n\x07version\x18\x02 \x01(\x05H\x00R\x07version\x88\x01\x01\x42\n\n\x08_version"5\n\x10GetOrderResponse\x12!\n\x05order\x18\x01 \x01(\x0b\x32\x0b.vega.OrderR\x05order"\xbd\x03\n\x0bOrderFilter\x12.\n\x08statuses\x18\x01 \x03(\x0e\x32\x12.vega.Order.StatusR\x08statuses\x12&\n\x05types\x18\x02 \x03(\x0e\x32\x10.vega.Order.TypeR\x05types\x12=\n\x0etime_in_forces\x18\x03 \x03(\x0e\x32\x17.vega.Order.TimeInForceR\x0ctimeInForces\x12+\n\x11\x65xclude_liquidity\x18\x04 \x01(\x08R\x10\x65xcludeLiquidity\x12\x1b\n\tparty_ids\x18\x05 \x03(\tR\x08partyIds\x12\x1d\n\nmarket_ids\x18\x06 \x03(\tR\tmarketIds\x12!\n\treference\x18\x07 \x01(\tH\x00R\treference\x88\x01\x01\x12>\n\ndate_range\x18\x08 \x01(\x0b\x32\x1a.datanode.api.v2.DateRangeH\x01R\tdateRange\x88\x01\x01\x12 \n\tlive_only\x18\t \x01(\x08H\x02R\x08liveOnly\x88\x01\x01\x42\x0c\n\n_referenceB\r\n\x0b_date_rangeB\x0c\n\n_live_only"\xaa\x01\n\x11ListOrdersRequest\x12@\n\npagination\x18\x02 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x00R\npagination\x88\x01\x01\x12\x39\n\x06\x66ilter\x18\x05 \x01(\x0b\x32\x1c.datanode.api.v2.OrderFilterH\x01R\x06\x66ilter\x88\x01\x01\x42\r\n\x0b_paginationB\t\n\x07_filter"N\n\x12ListOrdersResponse\x12\x38\n\x06orders\x18\x01 \x01(\x0b\x32 .datanode.api.v2.OrderConnectionR\x06orders"\x8c\x01\n\x18ListOrderVersionsRequest\x12\x1f\n\x08order_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x07orderId\x12@\n\npagination\x18\x04 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x00R\npagination\x88\x01\x01\x42\r\n\x0b_pagination"U\n\x19ListOrderVersionsResponse\x12\x38\n\x06orders\x18\x01 \x01(\x0b\x32 .datanode.api.v2.OrderConnectionR\x06orders"\x9a\x01\n\x14ObserveOrdersRequest\x12\x1d\n\nmarket_ids\x18\x01 \x03(\tR\tmarketIds\x12\x1b\n\tparty_ids\x18\x02 \x03(\tR\x08partyIds\x12\x30\n\x11\x65xclude_liquidity\x18\x03 \x01(\x08H\x00R\x10\x65xcludeLiquidity\x88\x01\x01\x42\x14\n\x12_exclude_liquidity"\xa0\x01\n\x15ObserveOrdersResponse\x12@\n\x08snapshot\x18\x01 \x01(\x0b\x32".datanode.api.v2.OrderSnapshotPageH\x00R\x08snapshot\x12\x39\n\x07updates\x18\x02 \x01(\x0b\x32\x1d.datanode.api.v2.OrderUpdatesH\x00R\x07updatesB\n\n\x08response"U\n\x11OrderSnapshotPage\x12#\n\x06orders\x18\x01 \x03(\x0b\x32\x0b.vega.OrderR\x06orders\x12\x1b\n\tlast_page\x18\x02 \x01(\x08R\x08lastPage"3\n\x0cOrderUpdates\x12#\n\x06orders\x18\x01 \x03(\x0b\x32\x0b.vega.OrderR\x06orders"6\n\x13GetStopOrderRequest\x12\x1f\n\x08order_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x07orderId"L\n\x14GetStopOrderResponse\x12\x34\n\x05order\x18\x01 \x01(\x0b\x32\x1e.vega.events.v1.StopOrderEventR\x05order"\xb2\x01\n\x15ListStopOrdersRequest\x12@\n\npagination\x18\x02 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x00R\npagination\x88\x01\x01\x12=\n\x06\x66ilter\x18\x05 \x01(\x0b\x32 .datanode.api.v2.StopOrderFilterH\x01R\x06\x66ilter\x88\x01\x01\x42\r\n\x0b_paginationB\t\n\x07_filter"\x9d\x02\n\x0fStopOrderFilter\x12\x32\n\x08statuses\x18\x01 \x03(\x0e\x32\x16.vega.StopOrder.StatusR\x08statuses\x12K\n\x11\x65xpiry_strategies\x18\x02 \x03(\x0e\x32\x1e.vega.StopOrder.ExpiryStrategyR\x10\x65xpiryStrategies\x12>\n\ndate_range\x18\x03 \x01(\x0b\x32\x1a.datanode.api.v2.DateRangeH\x00R\tdateRange\x88\x01\x01\x12\x1b\n\tparty_ids\x18\x04 \x03(\tR\x08partyIds\x12\x1d\n\nmarket_ids\x18\x05 \x03(\tR\tmarketIdsB\r\n\x0b_date_range"[\n\rStopOrderEdge\x12\x32\n\x04node\x18\x01 \x01(\x0b\x32\x1e.vega.events.v1.StopOrderEventR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x83\x01\n\x13StopOrderConnection\x12\x34\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x1e.datanode.api.v2.StopOrderEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"V\n\x16ListStopOrdersResponse\x12<\n\x06orders\x18\x01 \x01(\x0b\x32$.datanode.api.v2.StopOrderConnectionR\x06orders"\xa3\x01\n\x14ListPositionsRequest\x12\x19\n\x08party_id\x18\x01 \x01(\tR\x07partyId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12@\n\npagination\x18\x03 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x00R\npagination\x88\x01\x01:\x02\x18\x01\x42\r\n\x0b_pagination"^\n\x15ListPositionsResponse\x12\x41\n\tpositions\x18\x01 \x01(\x0b\x32#.datanode.api.v2.PositionConnectionR\tpositions:\x02\x18\x01"M\n\x0fPositionsFilter\x12\x1b\n\tparty_ids\x18\x01 \x03(\tR\x08partyIds\x12\x1d\n\nmarket_ids\x18\x02 \x03(\tR\tmarketIds"\xa4\x01\n\x17ListAllPositionsRequest\x12\x38\n\x06\x66ilter\x18\x01 \x01(\x0b\x32 .datanode.api.v2.PositionsFilterR\x06\x66ilter\x12@\n\npagination\x18\x02 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x00R\npagination\x88\x01\x01\x42\r\n\x0b_pagination"]\n\x18ListAllPositionsResponse\x12\x41\n\tpositions\x18\x01 \x01(\x0b\x32#.datanode.api.v2.PositionConnectionR\tpositions"J\n\x0cPositionEdge\x12"\n\x04node\x18\x01 \x01(\x0b\x32\x0e.vega.PositionR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x81\x01\n\x12PositionConnection\x12\x33\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x1d.datanode.api.v2.PositionEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"v\n\x17ObservePositionsRequest\x12\x1e\n\x08party_id\x18\x01 \x01(\tH\x00R\x07partyId\x88\x01\x01\x12 \n\tmarket_id\x18\x02 \x01(\tH\x01R\x08marketId\x88\x01\x01\x42\x0b\n\t_party_idB\x0c\n\n_market_id"\xa9\x01\n\x18ObservePositionsResponse\x12\x43\n\x08snapshot\x18\x01 \x01(\x0b\x32%.datanode.api.v2.PositionSnapshotPageH\x00R\x08snapshot\x12<\n\x07updates\x18\x02 \x01(\x0b\x32 .datanode.api.v2.PositionUpdatesH\x00R\x07updatesB\n\n\x08response"a\n\x14PositionSnapshotPage\x12,\n\tpositions\x18\x01 \x03(\x0b\x32\x0e.vega.PositionR\tpositions\x12\x1b\n\tlast_page\x18\x02 \x01(\x08R\x08lastPage"?\n\x0fPositionUpdates\x12,\n\tpositions\x18\x01 \x03(\x0b\x32\x0e.vega.PositionR\tpositions"\xa3\x02\n\x11LedgerEntryFilter\x12\x37\n\x18\x63lose_on_account_filters\x18\x01 \x01(\x08R\x15\x63loseOnAccountFilters\x12N\n\x13\x66rom_account_filter\x18\x02 \x01(\x0b\x32\x1e.datanode.api.v2.AccountFilterR\x11\x66romAccountFilter\x12J\n\x11to_account_filter\x18\x03 \x01(\x0b\x32\x1e.datanode.api.v2.AccountFilterR\x0ftoAccountFilter\x12\x39\n\x0etransfer_types\x18\x05 \x03(\x0e\x32\x12.vega.TransferTypeR\rtransferTypes"\xd9\x05\n\x15\x41ggregatedLedgerEntry\x12\x1c\n\ttimestamp\x18\x02 \x01(\x03R\ttimestamp\x12\x1a\n\x08quantity\x18\x03 \x01(\tR\x08quantity\x12\x37\n\rtransfer_type\x18\x04 \x01(\x0e\x32\x12.vega.TransferTypeR\x0ctransferType\x12\x1e\n\x08\x61sset_id\x18\x05 \x01(\tH\x00R\x07\x61ssetId\x88\x01\x01\x12=\n\x11\x66rom_account_type\x18\x06 \x01(\x0e\x32\x11.vega.AccountTypeR\x0f\x66romAccountType\x12\x39\n\x0fto_account_type\x18\x07 \x01(\x0e\x32\x11.vega.AccountTypeR\rtoAccountType\x12\x36\n\x15\x66rom_account_party_id\x18\x08 \x01(\tH\x01R\x12\x66romAccountPartyId\x88\x01\x01\x12\x32\n\x13to_account_party_id\x18\t \x01(\tH\x02R\x10toAccountPartyId\x88\x01\x01\x12\x38\n\x16\x66rom_account_market_id\x18\n \x01(\tH\x03R\x13\x66romAccountMarketId\x88\x01\x01\x12\x34\n\x14to_account_market_id\x18\x0b \x01(\tH\x04R\x11toAccountMarketId\x88\x01\x01\x12\x30\n\x14\x66rom_account_balance\x18\x0c \x01(\tR\x12\x66romAccountBalance\x12,\n\x12to_account_balance\x18\r \x01(\tR\x10toAccountBalanceB\x0b\n\t_asset_idB\x18\n\x16_from_account_party_idB\x16\n\x14_to_account_party_idB\x19\n\x17_from_account_market_idB\x17\n\x15_to_account_market_idJ\x04\x08\x01\x10\x02"\xf6\x01\n\x18ListLedgerEntriesRequest\x12:\n\x06\x66ilter\x18\x01 \x01(\x0b\x32".datanode.api.v2.LedgerEntryFilterR\x06\x66ilter\x12@\n\npagination\x18\x02 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x00R\npagination\x88\x01\x01\x12>\n\ndate_range\x18\x03 \x01(\x0b\x32\x1a.datanode.api.v2.DateRangeH\x01R\tdateRange\x88\x01\x01\x42\r\n\x0b_paginationB\r\n\x0b_date_range"\xad\x01\n\x1a\x45xportLedgerEntriesRequest\x12\x1f\n\x08party_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x07partyId\x12\x1f\n\x08\x61sset_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x07\x61ssetId\x12>\n\ndate_range\x18\x04 \x01(\x0b\x32\x1a.datanode.api.v2.DateRangeH\x00R\tdateRange\x88\x01\x01\x42\r\n\x0b_date_range"v\n\x19ListLedgerEntriesResponse\x12Y\n\x0eledger_entries\x18\x01 \x01(\x0b\x32\x32.datanode.api.v2.AggregatedLedgerEntriesConnectionR\rledgerEntries"q\n\x1b\x41ggregatedLedgerEntriesEdge\x12:\n\x04node\x18\x01 \x01(\x0b\x32&.datanode.api.v2.AggregatedLedgerEntryR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x9f\x01\n!AggregatedLedgerEntriesConnection\x12\x42\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32,.datanode.api.v2.AggregatedLedgerEntriesEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"\xf3\x01\n\x19ListBalanceChangesRequest\x12\x36\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x1e.datanode.api.v2.AccountFilterR\x06\x66ilter\x12@\n\npagination\x18\x05 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x00R\npagination\x88\x01\x01\x12>\n\ndate_range\x18\x06 \x01(\x0b\x32\x1a.datanode.api.v2.DateRangeH\x01R\tdateRange\x88\x01\x01\x42\r\n\x0b_paginationB\r\n\x0b_date_range"f\n\x1aListBalanceChangesResponse\x12H\n\x08\x62\x61lances\x18\x01 \x01(\x0b\x32,.datanode.api.v2.AggregatedBalanceConnectionR\x08\x62\x61lances"\xac\x02\n\x18GetBalanceHistoryRequest\x12\x36\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x1e.datanode.api.v2.AccountFilterR\x06\x66ilter\x12\x38\n\x08group_by\x18\x02 \x03(\x0e\x32\x1d.datanode.api.v2.AccountFieldR\x07groupBy\x12@\n\npagination\x18\x03 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x00R\npagination\x88\x01\x01\x12>\n\ndate_range\x18\x04 \x01(\x0b\x32\x1a.datanode.api.v2.DateRangeH\x01R\tdateRange\x88\x01\x01\x42\r\n\x0b_paginationB\r\n\x0b_date_range"e\n\x19GetBalanceHistoryResponse\x12H\n\x08\x62\x61lances\x18\x01 \x01(\x0b\x32,.datanode.api.v2.AggregatedBalanceConnectionR\x08\x62\x61lances"g\n\x15\x41ggregatedBalanceEdge\x12\x36\n\x04node\x18\x01 \x01(\x0b\x32".datanode.api.v2.AggregatedBalanceR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x93\x01\n\x1b\x41ggregatedBalanceConnection\x12<\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32&.datanode.api.v2.AggregatedBalanceEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"\x9e\x01\n\rAccountFilter\x12\x19\n\x08\x61sset_id\x18\x01 \x01(\tR\x07\x61ssetId\x12\x1b\n\tparty_ids\x18\x02 \x03(\tR\x08partyIds\x12\x1d\n\nmarket_ids\x18\x03 \x03(\tR\tmarketIds\x12\x36\n\raccount_types\x18\x04 \x03(\x0e\x32\x11.vega.AccountTypeR\x0c\x61\x63\x63ountTypes"\xa1\x02\n\x11\x41ggregatedBalance\x12\x1c\n\ttimestamp\x18\x01 \x01(\x03R\ttimestamp\x12\x18\n\x07\x62\x61lance\x18\x02 \x01(\tR\x07\x62\x61lance\x12\x1e\n\x08party_id\x18\x04 \x01(\tH\x00R\x07partyId\x88\x01\x01\x12\x1e\n\x08\x61sset_id\x18\x05 \x01(\tH\x01R\x07\x61ssetId\x88\x01\x01\x12 \n\tmarket_id\x18\x06 \x01(\tH\x02R\x08marketId\x88\x01\x01\x12\x39\n\x0c\x61\x63\x63ount_type\x18\x07 \x01(\x0e\x32\x11.vega.AccountTypeH\x03R\x0b\x61\x63\x63ountType\x88\x01\x01\x42\x0b\n\t_party_idB\x0b\n\t_asset_idB\x0c\n\n_market_idB\x0f\n\r_account_type";\n\x1aObserveMarketsDepthRequest\x12\x1d\n\nmarket_ids\x18\x01 \x03(\tR\tmarketIds"S\n\x1bObserveMarketsDepthResponse\x12\x34\n\x0cmarket_depth\x18\x01 \x03(\x0b\x32\x11.vega.MarketDepthR\x0bmarketDepth"B\n!ObserveMarketsDepthUpdatesRequest\x12\x1d\n\nmarket_ids\x18\x01 \x03(\tR\tmarketIds"U\n"ObserveMarketsDepthUpdatesResponse\x12/\n\x06update\x18\x01 \x03(\x0b\x32\x17.vega.MarketDepthUpdateR\x06update":\n\x19ObserveMarketsDataRequest\x12\x1d\n\nmarket_ids\x18\x01 \x03(\tR\tmarketIds"O\n\x1aObserveMarketsDataResponse\x12\x31\n\x0bmarket_data\x18\x01 \x03(\x0b\x32\x10.vega.MarketDataR\nmarketData"p\n\x1bGetLatestMarketDepthRequest\x12!\n\tmarket_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x08marketId\x12 \n\tmax_depth\x18\x02 \x01(\x04H\x00R\x08maxDepth\x88\x01\x01\x42\x0c\n\n_max_depth"\xda\x01\n\x1cGetLatestMarketDepthResponse\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12"\n\x03\x62uy\x18\x02 \x03(\x0b\x32\x10.vega.PriceLevelR\x03\x62uy\x12$\n\x04sell\x18\x03 \x03(\x0b\x32\x10.vega.PriceLevelR\x04sell\x12*\n\nlast_trade\x18\x04 \x01(\x0b\x32\x0b.vega.TradeR\tlastTrade\x12\'\n\x0fsequence_number\x18\x05 \x01(\x04R\x0esequenceNumber"\x1d\n\x1bListLatestMarketDataRequest"S\n\x1cListLatestMarketDataResponse\x12\x33\n\x0cmarkets_data\x18\x01 \x03(\x0b\x32\x10.vega.MarketDataR\x0bmarketsData"?\n\x1aGetLatestMarketDataRequest\x12!\n\tmarket_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x08marketId"P\n\x1bGetLatestMarketDataResponse\x12\x31\n\x0bmarket_data\x18\x01 \x01(\x0b\x32\x10.vega.MarketDataR\nmarketData"\x99\x02\n\x1fGetMarketDataHistoryByIDRequest\x12!\n\tmarket_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x08marketId\x12,\n\x0fstart_timestamp\x18\x02 \x01(\x03H\x00R\x0estartTimestamp\x88\x01\x01\x12(\n\rend_timestamp\x18\x03 \x01(\x03H\x01R\x0c\x65ndTimestamp\x88\x01\x01\x12@\n\npagination\x18\x04 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x02R\npagination\x88\x01\x01\x42\x12\n\x10_start_timestampB\x10\n\x0e_end_timestampB\r\n\x0b_paginationJ\x04\x08\x05\x10\x06"j\n GetMarketDataHistoryByIDResponse\x12\x46\n\x0bmarket_data\x18\x01 \x01(\x0b\x32%.datanode.api.v2.MarketDataConnectionR\nmarketData"N\n\x0eMarketDataEdge\x12$\n\x04node\x18\x01 \x01(\x0b\x32\x10.vega.MarketDataR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x85\x01\n\x14MarketDataConnection\x12\x35\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x1f.datanode.api.v2.MarketDataEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"\xd1\x01\n\x14ListTransfersRequest\x12\x1b\n\x06pubkey\x18\x01 \x01(\tH\x00R\x06pubkey\x88\x01\x01\x12@\n\tdirection\x18\x02 \x01(\x0e\x32".datanode.api.v2.TransferDirectionR\tdirection\x12@\n\npagination\x18\x03 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x01R\npagination\x88\x01\x01\x42\t\n\x07_pubkeyB\r\n\x0b_pagination"Z\n\x15ListTransfersResponse\x12\x41\n\ttransfers\x18\x01 \x01(\x0b\x32#.datanode.api.v2.TransferConnectionR\ttransfers"T\n\x0cTransferEdge\x12,\n\x04node\x18\x01 \x01(\x0b\x32\x18.vega.events.v1.TransferR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x81\x01\n\x12TransferConnection\x12\x33\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x1d.datanode.api.v2.TransferEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"\x19\n\x17GetNetworkLimitsRequest"G\n\x18GetNetworkLimitsResponse\x12+\n\x06limits\x18\x01 \x01(\x0b\x32\x13.vega.NetworkLimitsR\x06limits"?\n\x1aListCandleIntervalsRequest\x12!\n\tmarket_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x08marketId"M\n\x12IntervalToCandleId\x12\x1a\n\x08interval\x18\x01 \x01(\tR\x08interval\x12\x1b\n\tcandle_id\x18\x02 \x01(\tR\x08\x63\x61ndleId"u\n\x1bListCandleIntervalsResponse\x12V\n\x15interval_to_candle_id\x18\x01 \x03(\x0b\x32#.datanode.api.v2.IntervalToCandleIdR\x12intervalToCandleId"\xc3\x01\n\x06\x43\x61ndle\x12\x14\n\x05start\x18\x01 \x01(\x03R\x05start\x12\x1f\n\x0blast_update\x18\x02 \x01(\x03R\nlastUpdate\x12\x12\n\x04high\x18\x03 \x01(\tR\x04high\x12\x10\n\x03low\x18\x04 \x01(\tR\x03low\x12\x12\n\x04open\x18\x05 \x01(\tR\x04open\x12\x14\n\x05\x63lose\x18\x06 \x01(\tR\x05\x63lose\x12\x16\n\x06volume\x18\x07 \x01(\x04R\x06volume\x12\x1a\n\x08notional\x18\x08 \x01(\x04R\x08notional"=\n\x18ObserveCandleDataRequest\x12!\n\tcandle_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x08\x63\x61ndleId"L\n\x19ObserveCandleDataResponse\x12/\n\x06\x63\x61ndle\x18\x01 \x01(\x0b\x32\x17.datanode.api.v2.CandleR\x06\x63\x61ndle"\xdb\x01\n\x15ListCandleDataRequest\x12!\n\tcandle_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x08\x63\x61ndleId\x12%\n\x0e\x66rom_timestamp\x18\x02 \x01(\x03R\rfromTimestamp\x12!\n\x0cto_timestamp\x18\x03 \x01(\x03R\x0btoTimestamp\x12@\n\npagination\x18\x05 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x00R\npagination\x88\x01\x01\x42\r\n\x0b_paginationJ\x04\x08\x04\x10\x05"Y\n\x16ListCandleDataResponse\x12?\n\x07\x63\x61ndles\x18\x01 \x01(\x0b\x32%.datanode.api.v2.CandleDataConnectionR\x07\x63\x61ndles"Q\n\nCandleEdge\x12+\n\x04node\x18\x01 \x01(\x0b\x32\x17.datanode.api.v2.CandleR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x81\x01\n\x14\x43\x61ndleDataConnection\x12\x31\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x1b.datanode.api.v2.CandleEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"\xc6\x01\n\x10ListVotesRequest\x12\x1e\n\x08party_id\x18\x01 \x01(\tH\x00R\x07partyId\x88\x01\x01\x12$\n\x0bproposal_id\x18\x02 \x01(\tH\x01R\nproposalId\x88\x01\x01\x12@\n\npagination\x18\x03 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x02R\npagination\x88\x01\x01\x42\x0b\n\t_party_idB\x0e\n\x0c_proposal_idB\r\n\x0b_pagination"J\n\x11ListVotesResponse\x12\x35\n\x05votes\x18\x01 \x01(\x0b\x32\x1f.datanode.api.v2.VoteConnectionR\x05votes"B\n\x08VoteEdge\x12\x1e\n\x04node\x18\x01 \x01(\x0b\x32\n.vega.VoteR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"y\n\x0eVoteConnection\x12/\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x19.datanode.api.v2.VoteEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"x\n\x13ObserveVotesRequest\x12\x1e\n\x08party_id\x18\x01 \x01(\tH\x00R\x07partyId\x88\x01\x01\x12$\n\x0bproposal_id\x18\x02 \x01(\tH\x01R\nproposalId\x88\x01\x01\x42\x0b\n\t_party_idB\x0e\n\x0c_proposal_id"6\n\x14ObserveVotesResponse\x12\x1e\n\x04vote\x18\x01 \x01(\x0b\x32\n.vega.VoteR\x04vote"\xbd\x01\n*ListERC20MultiSigSignerAddedBundlesRequest\x12\x17\n\x07node_id\x18\x01 \x01(\tR\x06nodeId\x12\x1c\n\tsubmitter\x18\x02 \x01(\tR\tsubmitter\x12\x1b\n\tepoch_seq\x18\x03 \x01(\tR\x08\x65pochSeq\x12;\n\npagination\x18\x04 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationR\npagination"|\n+ListERC20MultiSigSignerAddedBundlesResponse\x12M\n\x07\x62undles\x18\x01 \x01(\x0b\x32\x33.datanode.api.v2.ERC20MultiSigSignerAddedConnectionR\x07\x62undles"t\n\x1c\x45RC20MultiSigSignerAddedEdge\x12<\n\x04node\x18\x01 \x01(\x0b\x32(.vega.events.v1.ERC20MultiSigSignerAddedR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x81\x01\n"ERC20MultiSigSignerAddedBundleEdge\x12\x43\n\x04node\x18\x01 \x01(\x0b\x32/.datanode.api.v2.ERC20MultiSigSignerAddedBundleR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\xa7\x01\n"ERC20MultiSigSignerAddedConnection\x12I\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x33.datanode.api.v2.ERC20MultiSigSignerAddedBundleEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"\xce\x01\n\x1e\x45RC20MultiSigSignerAddedBundle\x12\x1d\n\nnew_signer\x18\x01 \x01(\tR\tnewSigner\x12\x1c\n\tsubmitter\x18\x02 \x01(\tR\tsubmitter\x12\x14\n\x05nonce\x18\x04 \x01(\tR\x05nonce\x12\x1c\n\ttimestamp\x18\x05 \x01(\x03R\ttimestamp\x12\x1e\n\nsignatures\x18\x06 \x01(\tR\nsignatures\x12\x1b\n\tepoch_seq\x18\x03 \x01(\tR\x08\x65pochSeq"\xbf\x01\n,ListERC20MultiSigSignerRemovedBundlesRequest\x12\x17\n\x07node_id\x18\x01 \x01(\tR\x06nodeId\x12\x1c\n\tsubmitter\x18\x02 \x01(\tR\tsubmitter\x12\x1b\n\tepoch_seq\x18\x03 \x01(\tR\x08\x65pochSeq\x12;\n\npagination\x18\x04 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationR\npagination"\x80\x01\n-ListERC20MultiSigSignerRemovedBundlesResponse\x12O\n\x07\x62undles\x18\x01 \x01(\x0b\x32\x35.datanode.api.v2.ERC20MultiSigSignerRemovedConnectionR\x07\x62undles"x\n\x1e\x45RC20MultiSigSignerRemovedEdge\x12>\n\x04node\x18\x01 \x01(\x0b\x32*.vega.events.v1.ERC20MultiSigSignerRemovedR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x85\x01\n$ERC20MultiSigSignerRemovedBundleEdge\x12\x45\n\x04node\x18\x01 \x01(\x0b\x32\x31.datanode.api.v2.ERC20MultiSigSignerRemovedBundleR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\xab\x01\n$ERC20MultiSigSignerRemovedConnection\x12K\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x35.datanode.api.v2.ERC20MultiSigSignerRemovedBundleEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"\xd0\x01\n ERC20MultiSigSignerRemovedBundle\x12\x1d\n\nold_signer\x18\x01 \x01(\tR\toldSigner\x12\x1c\n\tsubmitter\x18\x02 \x01(\tR\tsubmitter\x12\x14\n\x05nonce\x18\x04 \x01(\tR\x05nonce\x12\x1c\n\ttimestamp\x18\x05 \x01(\x03R\ttimestamp\x12\x1e\n\nsignatures\x18\x06 \x01(\tR\nsignatures\x12\x1b\n\tepoch_seq\x18\x07 \x01(\tR\x08\x65pochSeq"A\n\x1eGetERC20ListAssetBundleRequest\x12\x1f\n\x08\x61sset_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x07\x61ssetId"\x9e\x01\n\x1fGetERC20ListAssetBundleResponse\x12!\n\x0c\x61sset_source\x18\x01 \x01(\tR\x0b\x61ssetSource\x12"\n\rvega_asset_id\x18\x02 \x01(\tR\x0bvegaAssetId\x12\x14\n\x05nonce\x18\x03 \x01(\tR\x05nonce\x12\x1e\n\nsignatures\x18\x04 \x01(\tR\nsignatures"L\n#GetERC20SetAssetLimitsBundleRequest\x12%\n\x0bproposal_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\nproposalId"\xe8\x01\n$GetERC20SetAssetLimitsBundleResponse\x12!\n\x0c\x61sset_source\x18\x01 \x01(\tR\x0b\x61ssetSource\x12"\n\rvega_asset_id\x18\x02 \x01(\tR\x0bvegaAssetId\x12\x14\n\x05nonce\x18\x03 \x01(\tR\x05nonce\x12%\n\x0elifetime_limit\x18\x04 \x01(\tR\rlifetimeLimit\x12\x1c\n\tthreshold\x18\x05 \x01(\tR\tthreshold\x12\x1e\n\nsignatures\x18\x06 \x01(\tR\nsignatures"N\n!GetERC20WithdrawalApprovalRequest\x12)\n\rwithdrawal_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x0cwithdrawalId"\xde\x01\n"GetERC20WithdrawalApprovalResponse\x12!\n\x0c\x61sset_source\x18\x01 \x01(\tR\x0b\x61ssetSource\x12\x16\n\x06\x61mount\x18\x02 \x01(\tR\x06\x61mount\x12\x14\n\x05nonce\x18\x04 \x01(\tR\x05nonce\x12\x1e\n\nsignatures\x18\x05 \x01(\tR\nsignatures\x12%\n\x0etarget_address\x18\x06 \x01(\tR\rtargetAddress\x12\x1a\n\x08\x63reation\x18\x07 \x01(\x03R\x08\x63reationJ\x04\x08\x03\x10\x04"8\n\x13GetLastTradeRequest\x12!\n\tmarket_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x08marketId"9\n\x14GetLastTradeResponse\x12!\n\x05trade\x18\x01 \x01(\x0b\x32\x0b.vega.TradeR\x05trade"\x8c\x02\n\x11ListTradesRequest\x12\x1d\n\nmarket_ids\x18\x01 \x03(\tR\tmarketIds\x12\x1b\n\torder_ids\x18\x02 \x03(\tR\x08orderIds\x12\x1b\n\tparty_ids\x18\x03 \x03(\tR\x08partyIds\x12@\n\npagination\x18\x04 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x00R\npagination\x88\x01\x01\x12>\n\ndate_range\x18\x05 \x01(\x0b\x32\x1a.datanode.api.v2.DateRangeH\x01R\tdateRange\x88\x01\x01\x42\r\n\x0b_paginationB\r\n\x0b_date_range"N\n\x12ListTradesResponse\x12\x38\n\x06trades\x18\x01 \x01(\x0b\x32 .datanode.api.v2.TradeConnectionR\x06trades"{\n\x0fTradeConnection\x12\x30\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x1a.datanode.api.v2.TradeEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"D\n\tTradeEdge\x12\x1f\n\x04node\x18\x01 \x01(\x0b\x32\x0b.vega.TradeR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"R\n\x14ObserveTradesRequest\x12\x1d\n\nmarket_ids\x18\x01 \x03(\tR\tmarketIds\x12\x1b\n\tparty_ids\x18\x02 \x03(\tR\x08partyIds"<\n\x15ObserveTradesResponse\x12#\n\x06trades\x18\x01 \x03(\x0b\x32\x0b.vega.TradeR\x06trades"B\n\x14GetOracleSpecRequest\x12*\n\x0eoracle_spec_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x0coracleSpecId"J\n\x15GetOracleSpecResponse\x12\x31\n\x0boracle_spec\x18\x01 \x01(\x0b\x32\x10.vega.OracleSpecR\noracleSpec"i\n\x16ListOracleSpecsRequest\x12@\n\npagination\x18\x02 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x00R\npagination\x88\x01\x01\x42\r\n\x0b_pagination"d\n\x17ListOracleSpecsResponse\x12I\n\x0coracle_specs\x18\x01 \x01(\x0b\x32&.datanode.api.v2.OracleSpecsConnectionR\x0boracleSpecs"\xa6\x01\n\x15ListOracleDataRequest\x12)\n\x0eoracle_spec_id\x18\x01 \x01(\tH\x00R\x0coracleSpecId\x88\x01\x01\x12@\n\npagination\x18\x02 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x01R\npagination\x88\x01\x01\x42\x11\n\x0f_oracle_spec_idB\r\n\x0b_pagination"`\n\x16ListOracleDataResponse\x12\x46\n\x0boracle_data\x18\x01 \x01(\x0b\x32%.datanode.api.v2.OracleDataConnectionR\noracleData"N\n\x0eOracleSpecEdge\x12$\n\x04node\x18\x01 \x01(\x0b\x32\x10.vega.OracleSpecR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x86\x01\n\x15OracleSpecsConnection\x12\x35\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x1f.datanode.api.v2.OracleSpecEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"N\n\x0eOracleDataEdge\x12$\n\x04node\x18\x01 \x01(\x0b\x32\x10.vega.OracleDataR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x85\x01\n\x14OracleDataConnection\x12\x35\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x1f.datanode.api.v2.OracleDataEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"5\n\x10GetMarketRequest\x12!\n\tmarket_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x08marketId"9\n\x11GetMarketResponse\x12$\n\x06market\x18\x01 \x01(\x0b\x32\x0c.vega.MarketR\x06market"\xa7\x01\n\x12ListMarketsRequest\x12@\n\npagination\x18\x02 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x00R\npagination\x88\x01\x01\x12,\n\x0finclude_settled\x18\x03 \x01(\x08H\x01R\x0eincludeSettled\x88\x01\x01\x42\r\n\x0b_paginationB\x12\n\x10_include_settled"R\n\x13ListMarketsResponse\x12;\n\x07markets\x18\x01 \x01(\x0b\x32!.datanode.api.v2.MarketConnectionR\x07markets"F\n\nMarketEdge\x12 \n\x04node\x18\x01 \x01(\x0b\x32\x0c.vega.MarketR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"}\n\x10MarketConnection\x12\x31\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x1b.datanode.api.v2.MarketEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"\xaf\x01\n\x1bListSuccessorMarketsRequest\x12!\n\tmarket_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x08marketId\x12\x30\n\x14include_full_history\x18\x02 \x01(\x08R\x12includeFullHistory\x12;\n\npagination\x18\x03 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationR\npagination"k\n\x0fSuccessorMarket\x12$\n\x06market\x18\x01 \x01(\x0b\x32\x0c.vega.MarketR\x06market\x12\x32\n\tproposals\x18\x02 \x03(\x0b\x32\x14.vega.GovernanceDataR\tproposals"c\n\x13SuccessorMarketEdge\x12\x34\n\x04node\x18\x01 \x01(\x0b\x32 .datanode.api.v2.SuccessorMarketR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x8f\x01\n\x19SuccessorMarketConnection\x12:\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32$.datanode.api.v2.SuccessorMarketEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"w\n\x1cListSuccessorMarketsResponse\x12W\n\x11successor_markets\x18\x01 \x01(\x0b\x32*.datanode.api.v2.SuccessorMarketConnectionR\x10successorMarkets"2\n\x0fGetPartyRequest\x12\x1f\n\x08party_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x07partyId"5\n\x10GetPartyResponse\x12!\n\x05party\x18\x01 \x01(\x0b\x32\x0b.vega.PartyR\x05party"l\n\x12ListPartiesRequest\x12\x19\n\x08party_id\x18\x01 \x01(\tR\x07partyId\x12;\n\npagination\x18\x02 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationR\npagination"Q\n\x13ListPartiesResponse\x12:\n\x07parties\x18\x01 \x01(\x0b\x32 .datanode.api.v2.PartyConnectionR\x07parties"D\n\tPartyEdge\x12\x1f\n\x04node\x18\x01 \x01(\x0b\x32\x0b.vega.PartyR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"{\n\x0fPartyConnection\x12\x30\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x1a.datanode.api.v2.PartyEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"D\n\tOrderEdge\x12\x1f\n\x04node\x18\x01 \x01(\x0b\x32\x0b.vega.OrderR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x8e\x01\n\x17ListMarginLevelsRequest\x12\x19\n\x08party_id\x18\x01 \x01(\tR\x07partyId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12;\n\npagination\x18\x03 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationR\npagination"b\n\x18ListMarginLevelsResponse\x12\x46\n\rmargin_levels\x18\x01 \x01(\x0b\x32!.datanode.api.v2.MarginConnectionR\x0cmarginLevels"g\n\x1aObserveMarginLevelsRequest\x12\x19\n\x08party_id\x18\x01 \x01(\tR\x07partyId\x12 \n\tmarket_id\x18\x02 \x01(\tH\x00R\x08marketId\x88\x01\x01\x42\x0c\n\n_market_id"V\n\x1bObserveMarginLevelsResponse\x12\x37\n\rmargin_levels\x18\x01 \x01(\x0b\x32\x12.vega.MarginLevelsR\x0cmarginLevels"{\n\x0fOrderConnection\x12\x30\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x1a.datanode.api.v2.OrderEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"L\n\nMarginEdge\x12&\n\x04node\x18\x01 \x01(\x0b\x32\x12.vega.MarginLevelsR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"}\n\x10MarginConnection\x12\x31\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x1b.datanode.api.v2.MarginEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"\x8d\x02\n\x12ListRewardsRequest\x12\x19\n\x08party_id\x18\x01 \x01(\tR\x07partyId\x12\x1e\n\x08\x61sset_id\x18\x02 \x01(\tH\x00R\x07\x61ssetId\x88\x01\x01\x12@\n\npagination\x18\x03 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x01R\npagination\x88\x01\x01\x12"\n\nfrom_epoch\x18\x04 \x01(\x04H\x02R\tfromEpoch\x88\x01\x01\x12\x1e\n\x08to_epoch\x18\x05 \x01(\x04H\x03R\x07toEpoch\x88\x01\x01\x42\x0b\n\t_asset_idB\r\n\x0b_paginationB\r\n\x0b_from_epochB\x0b\n\t_to_epoch"S\n\x13ListRewardsResponse\x12<\n\x07rewards\x18\x01 \x01(\x0b\x32".datanode.api.v2.RewardsConnectionR\x07rewards"F\n\nRewardEdge\x12 \n\x04node\x18\x01 \x01(\x0b\x32\x0c.vega.RewardR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"~\n\x11RewardsConnection\x12\x31\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x1b.datanode.api.v2.RewardEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"\xc7\x01\n\x1aListRewardSummariesRequest\x12\x1e\n\x08party_id\x18\x01 \x01(\tH\x00R\x07partyId\x88\x01\x01\x12\x1e\n\x08\x61sset_id\x18\x02 \x01(\tH\x01R\x07\x61ssetId\x88\x01\x01\x12@\n\npagination\x18\x03 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x02R\npagination\x88\x01\x01\x42\x0b\n\t_party_idB\x0b\n\t_asset_idB\r\n\x0b_pagination"P\n\x1bListRewardSummariesResponse\x12\x31\n\tsummaries\x18\x01 \x03(\x0b\x32\x13.vega.RewardSummaryR\tsummaries"\xb1\x01\n\x13RewardSummaryFilter\x12\x1b\n\tasset_ids\x18\x01 \x03(\tR\x08\x61ssetIds\x12\x1d\n\nmarket_ids\x18\x02 \x03(\tR\tmarketIds\x12"\n\nfrom_epoch\x18\x03 \x01(\x04H\x00R\tfromEpoch\x88\x01\x01\x12\x1e\n\x08to_epoch\x18\x04 \x01(\x04H\x01R\x07toEpoch\x88\x01\x01\x42\r\n\x0b_from_epochB\x0b\n\t_to_epoch"\xb0\x01\n\x1fListEpochRewardSummariesRequest\x12<\n\x06\x66ilter\x18\x01 \x01(\x0b\x32$.datanode.api.v2.RewardSummaryFilterR\x06\x66ilter\x12@\n\npagination\x18\x04 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x00R\npagination\x88\x01\x01\x42\r\n\x0b_pagination"o\n ListEpochRewardSummariesResponse\x12K\n\tsummaries\x18\x01 \x01(\x0b\x32-.datanode.api.v2.EpochRewardSummaryConnectionR\tsummaries"\x95\x01\n\x1c\x45pochRewardSummaryConnection\x12=\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\'.datanode.api.v2.EpochRewardSummaryEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"^\n\x16\x45pochRewardSummaryEdge\x12,\n\x04node\x18\x01 \x01(\x0b\x32\x18.vega.EpochRewardSummaryR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"q\n\x15ObserveRewardsRequest\x12\x1e\n\x08\x61sset_id\x18\x01 \x01(\tH\x00R\x07\x61ssetId\x88\x01\x01\x12\x1e\n\x08party_id\x18\x02 \x01(\tH\x01R\x07partyId\x88\x01\x01\x42\x0b\n\t_asset_idB\x0b\n\t_party_id">\n\x16ObserveRewardsResponse\x12$\n\x06reward\x18\x01 \x01(\x0b\x32\x0c.vega.RewardR\x06reward")\n\x11GetDepositRequest\x12\x14\n\x02id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x02id"=\n\x12GetDepositResponse\x12\'\n\x07\x64\x65posit\x18\x01 \x01(\x0b\x32\r.vega.DepositR\x07\x64\x65posit"\xd0\x01\n\x13ListDepositsRequest\x12\x19\n\x08party_id\x18\x01 \x01(\tR\x07partyId\x12@\n\npagination\x18\x02 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x00R\npagination\x88\x01\x01\x12>\n\ndate_range\x18\x03 \x01(\x0b\x32\x1a.datanode.api.v2.DateRangeH\x01R\tdateRange\x88\x01\x01\x42\r\n\x0b_paginationB\r\n\x0b_date_range"W\n\x14ListDepositsResponse\x12?\n\x08\x64\x65posits\x18\x01 \x01(\x0b\x32#.datanode.api.v2.DepositsConnectionR\x08\x64\x65posits"H\n\x0b\x44\x65positEdge\x12!\n\x04node\x18\x01 \x01(\x0b\x32\r.vega.DepositR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x80\x01\n\x12\x44\x65positsConnection\x12\x32\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x1c.datanode.api.v2.DepositEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo",\n\x14GetWithdrawalRequest\x12\x14\n\x02id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x02id"I\n\x15GetWithdrawalResponse\x12\x30\n\nwithdrawal\x18\x01 \x01(\x0b\x32\x10.vega.WithdrawalR\nwithdrawal"\xd3\x01\n\x16ListWithdrawalsRequest\x12\x19\n\x08party_id\x18\x01 \x01(\tR\x07partyId\x12@\n\npagination\x18\x02 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x00R\npagination\x88\x01\x01\x12>\n\ndate_range\x18\x03 \x01(\x0b\x32\x1a.datanode.api.v2.DateRangeH\x01R\tdateRange\x88\x01\x01\x42\r\n\x0b_paginationB\r\n\x0b_date_range"c\n\x17ListWithdrawalsResponse\x12H\n\x0bwithdrawals\x18\x01 \x01(\x0b\x32&.datanode.api.v2.WithdrawalsConnectionR\x0bwithdrawals"N\n\x0eWithdrawalEdge\x12$\n\x04node\x18\x01 \x01(\x0b\x32\x10.vega.WithdrawalR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x86\x01\n\x15WithdrawalsConnection\x12\x35\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x1f.datanode.api.v2.WithdrawalEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"2\n\x0fGetAssetRequest\x12\x1f\n\x08\x61sset_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x07\x61ssetId"5\n\x10GetAssetResponse\x12!\n\x05\x61sset\x18\x01 \x01(\x0b\x32\x0b.vega.AssetR\x05\x61sset"\x91\x01\n\x11ListAssetsRequest\x12\x1e\n\x08\x61sset_id\x18\x01 \x01(\tH\x00R\x07\x61ssetId\x88\x01\x01\x12@\n\npagination\x18\x02 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x01R\npagination\x88\x01\x01\x42\x0b\n\t_asset_idB\r\n\x0b_pagination"O\n\x12ListAssetsResponse\x12\x39\n\x06\x61ssets\x18\x01 \x01(\x0b\x32!.datanode.api.v2.AssetsConnectionR\x06\x61ssets"D\n\tAssetEdge\x12\x1f\n\x04node\x18\x01 \x01(\x0b\x32\x0b.vega.AssetR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"|\n\x10\x41ssetsConnection\x12\x30\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x1a.datanode.api.v2.AssetEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"\xa1\x02\n\x1eListLiquidityProvisionsRequest\x12 \n\tmarket_id\x18\x01 \x01(\tH\x00R\x08marketId\x88\x01\x01\x12\x1e\n\x08party_id\x18\x02 \x01(\tH\x01R\x07partyId\x88\x01\x01\x12!\n\treference\x18\x03 \x01(\tH\x02R\treference\x88\x01\x01\x12\x17\n\x04live\x18\x04 \x01(\x08H\x03R\x04live\x88\x01\x01\x12@\n\npagination\x18\x05 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x04R\npagination\x88\x01\x01\x42\x0c\n\n_market_idB\x0b\n\t_party_idB\x0c\n\n_referenceB\x07\n\x05_liveB\r\n\x0b_pagination"\x84\x01\n\x1fListLiquidityProvisionsResponse\x12\x61\n\x14liquidity_provisions\x18\x01 \x01(\x0b\x32..datanode.api.v2.LiquidityProvisionsConnectionR\x13liquidityProvisions"_\n\x17LiquidityProvisionsEdge\x12,\n\x04node\x18\x01 \x01(\x0b\x32\x18.vega.LiquidityProvisionR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x97\x01\n\x1dLiquidityProvisionsConnection\x12>\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32(.datanode.api.v2.LiquidityProvisionsEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"\x80\x01\n!ObserveLiquidityProvisionsRequest\x12 \n\tmarket_id\x18\x01 \x01(\tH\x00R\x08marketId\x88\x01\x01\x12\x1e\n\x08party_id\x18\x02 \x01(\tH\x01R\x07partyId\x88\x01\x01\x42\x0c\n\n_market_idB\x0b\n\t_party_id"q\n"ObserveLiquidityProvisionsResponse\x12K\n\x14liquidity_provisions\x18\x01 \x03(\x0b\x32\x18.vega.LiquidityProvisionR\x13liquidityProvisions"\x81\x01\n\x18GetGovernanceDataRequest\x12$\n\x0bproposal_id\x18\x01 \x01(\tH\x00R\nproposalId\x88\x01\x01\x12!\n\treference\x18\x02 \x01(\tH\x01R\treference\x88\x01\x01\x42\x0e\n\x0c_proposal_idB\x0c\n\n_reference"E\n\x19GetGovernanceDataResponse\x12(\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x14.vega.GovernanceDataR\x04\x64\x61ta"\xfa\x04\n\x19ListGovernanceDataRequest\x12@\n\x0eproposal_state\x18\x01 \x01(\x0e\x32\x14.vega.Proposal.StateH\x00R\rproposalState\x88\x01\x01\x12Y\n\rproposal_type\x18\x02 \x01(\x0e\x32/.datanode.api.v2.ListGovernanceDataRequest.TypeH\x01R\x0cproposalType\x88\x01\x01\x12/\n\x11proposer_party_id\x18\x03 \x01(\tH\x02R\x0fproposerPartyId\x88\x01\x01\x12\x32\n\x12proposal_reference\x18\x04 \x01(\tH\x03R\x11proposalReference\x88\x01\x01\x12@\n\npagination\x18\x05 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x04R\npagination\x88\x01\x01"\xb7\x01\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x0c\n\x08TYPE_ALL\x10\x01\x12\x13\n\x0fTYPE_NEW_MARKET\x10\x02\x12\x16\n\x12TYPE_UPDATE_MARKET\x10\x03\x12\x1b\n\x17TYPE_NETWORK_PARAMETERS\x10\x04\x12\x12\n\x0eTYPE_NEW_ASSET\x10\x05\x12\x16\n\x12TYPE_NEW_FREE_FORM\x10\x06\x12\x15\n\x11TYPE_UPDATE_ASSET\x10\x07\x42\x11\n\x0f_proposal_stateB\x10\n\x0e_proposal_typeB\x14\n\x12_proposer_party_idB\x15\n\x13_proposal_referenceB\r\n\x0b_pagination"g\n\x1aListGovernanceDataResponse\x12I\n\nconnection\x18\x01 \x01(\x0b\x32).datanode.api.v2.GovernanceDataConnectionR\nconnection"V\n\x12GovernanceDataEdge\x12(\n\x04node\x18\x01 \x01(\x0b\x32\x14.vega.GovernanceDataR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x8d\x01\n\x18GovernanceDataConnection\x12\x39\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32#.datanode.api.v2.GovernanceDataEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"G\n\x18ObserveGovernanceRequest\x12\x1e\n\x08party_id\x18\x01 \x01(\tH\x00R\x07partyId\x88\x01\x01\x42\x0b\n\t_party_id"E\n\x19ObserveGovernanceResponse\x12(\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x14.vega.GovernanceDataR\x04\x64\x61ta"\xed\x01\n\x16ListDelegationsRequest\x12\x1e\n\x08party_id\x18\x01 \x01(\tH\x00R\x07partyId\x88\x01\x01\x12\x1c\n\x07node_id\x18\x02 \x01(\tH\x01R\x06nodeId\x88\x01\x01\x12\x1e\n\x08\x65poch_id\x18\x03 \x01(\tH\x02R\x07\x65pochId\x88\x01\x01\x12@\n\npagination\x18\x04 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x03R\npagination\x88\x01\x01\x42\x0b\n\t_party_idB\n\n\x08_node_idB\x0b\n\t_epoch_idB\r\n\x0b_pagination"c\n\x17ListDelegationsResponse\x12H\n\x0b\x64\x65legations\x18\x01 \x01(\x0b\x32&.datanode.api.v2.DelegationsConnectionR\x0b\x64\x65legations"N\n\x0e\x44\x65legationEdge\x12$\n\x04node\x18\x01 \x01(\x0b\x32\x10.vega.DelegationR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x86\x01\n\x15\x44\x65legationsConnection\x12\x35\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x1f.datanode.api.v2.DelegationEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"r\n\x19ObserveDelegationsRequest\x12\x1e\n\x08party_id\x18\x01 \x01(\tH\x00R\x07partyId\x88\x01\x01\x12\x1c\n\x07node_id\x18\x02 \x01(\tH\x01R\x06nodeId\x88\x01\x01\x42\x0b\n\t_party_idB\n\n\x08_node_id"N\n\x1aObserveDelegationsResponse\x12\x30\n\ndelegation\x18\x01 \x01(\x0b\x32\x10.vega.DelegationR\ndelegation"\x91\x02\n\tNodeBasic\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x17\n\x07pub_key\x18\x02 \x01(\tR\x06pubKey\x12\x1c\n\ntm_pub_key\x18\x03 \x01(\tR\x08tmPubKey\x12)\n\x10\x65thereum_address\x18\x04 \x01(\tR\x0f\x65thereumAddress\x12\x19\n\x08info_url\x18\x05 \x01(\tR\x07infoUrl\x12\x1a\n\x08location\x18\x06 \x01(\tR\x08location\x12(\n\x06status\x18\r \x01(\x0e\x32\x10.vega.NodeStatusR\x06status\x12\x12\n\x04name\x18\x11 \x01(\tR\x04name\x12\x1d\n\navatar_url\x18\x12 \x01(\tR\tavatarUrl"\x17\n\x15GetNetworkDataRequest"E\n\x16GetNetworkDataResponse\x12+\n\tnode_data\x18\x01 \x01(\x0b\x32\x0e.vega.NodeDataR\x08nodeData"&\n\x0eGetNodeRequest\x12\x14\n\x02id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x02id"1\n\x0fGetNodeResponse\x12\x1e\n\x04node\x18\x01 \x01(\x0b\x32\n.vega.NodeR\x04node"\x93\x01\n\x10ListNodesRequest\x12 \n\tepoch_seq\x18\x01 \x01(\x04H\x00R\x08\x65pochSeq\x88\x01\x01\x12@\n\npagination\x18\x02 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x01R\npagination\x88\x01\x01\x42\x0c\n\n_epoch_seqB\r\n\x0b_pagination"K\n\x11ListNodesResponse\x12\x36\n\x05nodes\x18\x01 \x01(\x0b\x32 .datanode.api.v2.NodesConnectionR\x05nodes"B\n\x08NodeEdge\x12\x1e\n\x04node\x18\x01 \x01(\x0b\x32\n.vega.NodeR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"z\n\x0fNodesConnection\x12/\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x19.datanode.api.v2.NodeEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"\x82\x01\n\x19ListNodeSignaturesRequest\x12\x14\n\x02id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x02id\x12@\n\npagination\x18\x02 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x00R\npagination\x88\x01\x01\x42\r\n\x0b_pagination"g\n\x1aListNodeSignaturesResponse\x12I\n\nsignatures\x18\x01 \x01(\x0b\x32).datanode.api.v2.NodeSignaturesConnectionR\nsignatures"`\n\x11NodeSignatureEdge\x12\x33\n\x04node\x18\x01 \x01(\x0b\x32\x1f.vega.commands.v1.NodeSignatureR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x8c\x01\n\x18NodeSignaturesConnection\x12\x38\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32".datanode.api.v2.NodeSignatureEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"R\n\x0fGetEpochRequest\x12\x13\n\x02id\x18\x01 \x01(\x04H\x00R\x02id\x88\x01\x01\x12\x19\n\x05\x62lock\x18\x02 \x01(\x04H\x01R\x05\x62lock\x88\x01\x01\x42\x05\n\x03_idB\x08\n\x06_block"5\n\x10GetEpochResponse\x12!\n\x05\x65poch\x18\x01 \x01(\x0b\x32\x0b.vega.EpochR\x05\x65poch"m\n\x12\x45stimateFeeRequest\x12!\n\tmarket_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x08marketId\x12\x1a\n\x05price\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x05price\x12\x18\n\x04size\x18\x03 \x01(\x04\x42\x04\xe2\x41\x01\x02R\x04size"2\n\x13\x45stimateFeeResponse\x12\x1b\n\x03\x66\x65\x65\x18\x02 \x01(\x0b\x32\t.vega.FeeR\x03\x66\x65\x65"\xe7\x01\n\x15\x45stimateMarginRequest\x12!\n\tmarket_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x08marketId\x12\x1f\n\x08party_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x07partyId\x12$\n\x04side\x18\x03 \x01(\x0e\x32\n.vega.SideB\x04\xe2\x41\x01\x02R\x04side\x12*\n\x04type\x18\x04 \x01(\x0e\x32\x10.vega.Order.TypeB\x04\xe2\x41\x01\x02R\x04type\x12\x18\n\x04size\x18\x05 \x01(\x04\x42\x04\xe2\x41\x01\x02R\x04size\x12\x1a\n\x05price\x18\x06 \x01(\tB\x04\xe2\x41\x01\x02R\x05price:\x02\x18\x01"U\n\x16\x45stimateMarginResponse\x12\x37\n\rmargin_levels\x18\x02 \x01(\x0b\x32\x12.vega.MarginLevelsR\x0cmarginLevels:\x02\x18\x01"o\n\x1cListNetworkParametersRequest\x12@\n\npagination\x18\x01 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x00R\npagination\x88\x01\x01\x42\r\n\x0b_pagination"{\n\x1dListNetworkParametersResponse\x12Z\n\x12network_parameters\x18\x01 \x01(\x0b\x32+.datanode.api.v2.NetworkParameterConnectionR\x11networkParameters"4\n\x1aGetNetworkParameterRequest\x12\x16\n\x03key\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x03key"b\n\x1bGetNetworkParameterResponse\x12\x43\n\x11network_parameter\x18\x01 \x01(\x0b\x32\x16.vega.NetworkParameterR\x10networkParameter"Z\n\x14NetworkParameterEdge\x12*\n\x04node\x18\x01 \x01(\x0b\x32\x16.vega.NetworkParameterR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x91\x01\n\x1aNetworkParameterConnection\x12;\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32%.datanode.api.v2.NetworkParameterEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"Z\n\nCheckpoint\x12\x12\n\x04hash\x18\x01 \x01(\tR\x04hash\x12\x1d\n\nblock_hash\x18\x02 \x01(\tR\tblockHash\x12\x19\n\x08\x61t_block\x18\x03 \x01(\x04R\x07\x61tBlock"i\n\x16ListCheckpointsRequest\x12@\n\npagination\x18\x01 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x00R\npagination\x88\x01\x01\x42\r\n\x0b_pagination"c\n\x17ListCheckpointsResponse\x12H\n\x0b\x63heckpoints\x18\x01 \x01(\x0b\x32&.datanode.api.v2.CheckpointsConnectionR\x0b\x63heckpoints"Y\n\x0e\x43heckpointEdge\x12/\n\x04node\x18\x01 \x01(\x0b\x32\x1b.datanode.api.v2.CheckpointR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x86\x01\n\x15\x43heckpointsConnection\x12\x35\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x1f.datanode.api.v2.CheckpointEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"\x83\x01\n\x0fGetStakeRequest\x12\x1f\n\x08party_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x07partyId\x12@\n\npagination\x18\x02 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x00R\npagination\x88\x01\x01\x42\r\n\x0b_pagination"\x94\x01\n\x10GetStakeResponse\x12\x36\n\x17\x63urrent_stake_available\x18\x01 \x01(\tR\x15\x63urrentStakeAvailable\x12H\n\x0estake_linkings\x18\x02 \x01(\x0b\x32!.datanode.api.v2.StakesConnectionR\rstakeLinkings"\\\n\x10StakeLinkingEdge\x12\x30\n\x04node\x18\x01 \x01(\x0b\x32\x1c.vega.events.v1.StakeLinkingR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x83\x01\n\x10StakesConnection\x12\x37\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32!.datanode.api.v2.StakeLinkingEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo":\n\x15GetRiskFactorsRequest\x12!\n\tmarket_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x08marketId"K\n\x16GetRiskFactorsResponse\x12\x31\n\x0brisk_factor\x18\x01 \x01(\x0b\x32\x10.vega.RiskFactorR\nriskFactor"\xa1\x01\n\x16ObserveEventBusRequest\x12\x30\n\x04type\x18\x01 \x03(\x0e\x32\x1c.vega.events.v1.BusEventTypeR\x04type\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12\x19\n\x08party_id\x18\x03 \x01(\tR\x07partyId\x12\x1d\n\nbatch_size\x18\x04 \x01(\x03R\tbatchSize"K\n\x17ObserveEventBusResponse\x12\x30\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x18.vega.events.v1.BusEventR\x06\x65vents"\x1f\n\x1dObserveLedgerMovementsRequest"_\n\x1eObserveLedgerMovementsResponse\x12=\n\x0fledger_movement\x18\x01 \x01(\x0b\x32\x14.vega.LedgerMovementR\x0eledgerMovement"\x94\x01\n\x17ListKeyRotationsRequest\x12\x1c\n\x07node_id\x18\x01 \x01(\tH\x00R\x06nodeId\x88\x01\x01\x12@\n\npagination\x18\x02 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x01R\npagination\x88\x01\x01\x42\n\n\x08_node_idB\r\n\x0b_pagination"`\n\x18ListKeyRotationsResponse\x12\x44\n\trotations\x18\x01 \x01(\x0b\x32&.datanode.api.v2.KeyRotationConnectionR\trotations"Z\n\x0fKeyRotationEdge\x12/\n\x04node\x18\x01 \x01(\x0b\x32\x1b.vega.events.v1.KeyRotationR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x87\x01\n\x15KeyRotationConnection\x12\x36\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32 .datanode.api.v2.KeyRotationEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"\x9c\x01\n\x1fListEthereumKeyRotationsRequest\x12\x1c\n\x07node_id\x18\x01 \x01(\tH\x00R\x06nodeId\x88\x01\x01\x12@\n\npagination\x18\x02 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x01R\npagination\x88\x01\x01\x42\n\n\x08_node_idB\r\n\x0b_pagination"x\n ListEthereumKeyRotationsResponse\x12T\n\rkey_rotations\x18\x01 \x01(\x0b\x32/.datanode.api.v2.EthereumKeyRotationsConnectionR\x0ckeyRotations"\x98\x01\n\x1e\x45thereumKeyRotationsConnection\x12>\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32(.datanode.api.v2.EthereumKeyRotationEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"j\n\x17\x45thereumKeyRotationEdge\x12\x37\n\x04node\x18\x01 \x01(\x0b\x32#.vega.events.v1.EthereumKeyRotationR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x14\n\x12GetVegaTimeRequest"3\n\x13GetVegaTimeResponse\x12\x1c\n\ttimestamp\x18\x01 \x01(\x03R\ttimestamp"\x89\x01\n\tDateRange\x12,\n\x0fstart_timestamp\x18\x01 \x01(\x03H\x00R\x0estartTimestamp\x88\x01\x01\x12(\n\rend_timestamp\x18\x02 \x01(\x03H\x01R\x0c\x65ndTimestamp\x88\x01\x01\x42\x12\n\x10_start_timestampB\x10\n\x0e_end_timestamp"!\n\x1fGetProtocolUpgradeStatusRequest"8\n GetProtocolUpgradeStatusResponse\x12\x14\n\x05ready\x18\x01 \x01(\x08R\x05ready"\x83\x02\n#ListProtocolUpgradeProposalsRequest\x12J\n\x06status\x18\x01 \x01(\x0e\x32-.vega.events.v1.ProtocolUpgradeProposalStatusH\x00R\x06status\x88\x01\x01\x12$\n\x0b\x61pproved_by\x18\x02 \x01(\tH\x01R\napprovedBy\x88\x01\x01\x12@\n\npagination\x18\x03 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x02R\npagination\x88\x01\x01\x42\t\n\x07_statusB\x0e\n\x0c_approved_byB\r\n\x0b_pagination"\x98\x01\n$ListProtocolUpgradeProposalsResponse\x12p\n\x1aprotocol_upgrade_proposals\x18\x01 \x01(\x0b\x32\x32.datanode.api.v2.ProtocolUpgradeProposalConnectionR\x18protocolUpgradeProposals"\x9f\x01\n!ProtocolUpgradeProposalConnection\x12\x42\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32,.datanode.api.v2.ProtocolUpgradeProposalEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"o\n\x1bProtocolUpgradeProposalEdge\x12\x38\n\x04node\x18\x01 \x01(\x0b\x32$.vega.events.v1.ProtocolUpgradeEventR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"k\n\x18ListCoreSnapshotsRequest\x12@\n\npagination\x18\x01 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x00R\npagination\x88\x01\x01\x42\r\n\x0b_pagination"k\n\x19ListCoreSnapshotsResponse\x12N\n\x0e\x63ore_snapshots\x18\x01 \x01(\x0b\x32\'.datanode.api.v2.CoreSnapshotConnectionR\rcoreSnapshots"\x89\x01\n\x16\x43oreSnapshotConnection\x12\x37\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32!.datanode.api.v2.CoreSnapshotEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"`\n\x10\x43oreSnapshotEdge\x12\x34\n\x04node\x18\x01 \x01(\x0b\x32 .vega.events.v1.CoreSnapshotDataR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x81\x02\n\x0eHistorySegment\x12\x1f\n\x0b\x66rom_height\x18\x01 \x01(\x03R\nfromHeight\x12\x1b\n\tto_height\x18\x02 \x01(\x03R\x08toHeight\x12,\n\x12history_segment_id\x18\x03 \x01(\tR\x10historySegmentId\x12=\n\x1bprevious_history_segment_id\x18\x04 \x01(\tR\x18previousHistorySegmentId\x12)\n\x10\x64\x61tabase_version\x18\x05 \x01(\x03R\x0f\x64\x61tabaseVersion\x12\x19\n\x08\x63hain_id\x18\x06 \x01(\tR\x07\x63hainId"+\n)GetMostRecentNetworkHistorySegmentRequest"\x8d\x01\n*GetMostRecentNetworkHistorySegmentResponse\x12\x39\n\x07segment\x18\x01 \x01(\x0b\x32\x1f.datanode.api.v2.HistorySegmentR\x07segment\x12$\n\x0eswarm_key_seed\x18\x02 \x01(\tR\x0cswarmKeySeed"&\n$ListAllNetworkHistorySegmentsRequest"d\n%ListAllNetworkHistorySegmentsResponse\x12;\n\x08segments\x18\x01 \x03(\x0b\x32\x1f.datanode.api.v2.HistorySegmentR\x08segments"-\n+GetActiveNetworkHistoryPeerAddressesRequest"Q\n,GetActiveNetworkHistoryPeerAddressesResponse\x12!\n\x0cip_addresses\x18\x01 \x03(\tR\x0bipAddresses" \n\x1eGetNetworkHistoryStatusRequest"\xb0\x01\n\x1fGetNetworkHistoryStatusResponse\x12!\n\x0cipfs_address\x18\x01 \x01(\tR\x0bipfsAddress\x12\x1b\n\tswarm_key\x18\x02 \x01(\tR\x08swarmKey\x12$\n\x0eswarm_key_seed\x18\x03 \x01(\tR\x0cswarmKeySeed\x12\'\n\x0f\x63onnected_peers\x18\x05 \x03(\tR\x0e\x63onnectedPeers"(\n&GetNetworkHistoryBootstrapPeersRequest"R\n\'GetNetworkHistoryBootstrapPeersResponse\x12\'\n\x0f\x62ootstrap_peers\x18\x01 \x03(\tR\x0e\x62ootstrapPeers"\x85\x01\n\x1b\x45xportNetworkHistoryRequest\x12\x1d\n\nfrom_block\x18\x01 \x01(\x03R\tfromBlock\x12\x19\n\x08to_block\x18\x02 \x01(\x03R\x07toBlock\x12,\n\x05table\x18\x03 \x01(\x0e\x32\x16.datanode.api.v2.TableR\x05table"F\n\x13ListEntitiesRequest\x12/\n\x10transaction_hash\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x0ftransactionHash"\xad\r\n\x14ListEntitiesResponse\x12)\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32\r.vega.AccountR\x08\x61\x63\x63ounts\x12#\n\x06orders\x18\x02 \x03(\x0b\x32\x0b.vega.OrderR\x06orders\x12,\n\tpositions\x18\x03 \x03(\x0b\x32\x0e.vega.PositionR\tpositions\x12\x38\n\x0eledger_entries\x18\x04 \x03(\x0b\x32\x11.vega.LedgerEntryR\rledgerEntries\x12H\n\x0f\x62\x61lance_changes\x18\x05 \x03(\x0b\x32\x1f.datanode.api.v2.AccountBalanceR\x0e\x62\x61lanceChanges\x12\x36\n\ttransfers\x18\x06 \x03(\x0b\x32\x18.vega.events.v1.TransferR\ttransfers\x12 \n\x05votes\x18\x07 \x03(\x0b\x32\n.vega.VoteR\x05votes\x12~\n$erc20_multi_sig_signer_added_bundles\x18\x08 \x03(\x0b\x32/.datanode.api.v2.ERC20MultiSigSignerAddedBundleR\x1f\x65rc20MultiSigSignerAddedBundles\x12\x84\x01\n&erc20_multi_sig_signer_removed_bundles\x18\t \x03(\x0b\x32\x31.datanode.api.v2.ERC20MultiSigSignerRemovedBundleR!erc20MultiSigSignerRemovedBundles\x12#\n\x06trades\x18\n \x03(\x0b\x32\x0b.vega.TradeR\x06trades\x12\x33\n\x0coracle_specs\x18\x0b \x03(\x0b\x32\x10.vega.OracleSpecR\x0boracleSpecs\x12\x31\n\x0boracle_data\x18\x0c \x03(\x0b\x32\x10.vega.OracleDataR\noracleData\x12&\n\x07markets\x18\r \x03(\x0b\x32\x0c.vega.MarketR\x07markets\x12%\n\x07parties\x18\x0e \x03(\x0b\x32\x0b.vega.PartyR\x07parties\x12\x37\n\rmargin_levels\x18\x0f \x03(\x0b\x32\x12.vega.MarginLevelsR\x0cmarginLevels\x12&\n\x07rewards\x18\x10 \x03(\x0b\x32\x0c.vega.RewardR\x07rewards\x12)\n\x08\x64\x65posits\x18\x11 \x03(\x0b\x32\r.vega.DepositR\x08\x64\x65posits\x12\x32\n\x0bwithdrawals\x18\x12 \x03(\x0b\x32\x10.vega.WithdrawalR\x0bwithdrawals\x12#\n\x06\x61ssets\x18\x13 \x03(\x0b\x32\x0b.vega.AssetR\x06\x61ssets\x12K\n\x14liquidity_provisions\x18\x14 \x03(\x0b\x32\x18.vega.LiquidityProvisionR\x13liquidityProvisions\x12,\n\tproposals\x18\x15 \x03(\x0b\x32\x0e.vega.ProposalR\tproposals\x12\x32\n\x0b\x64\x65legations\x18\x16 \x03(\x0b\x32\x10.vega.DelegationR\x0b\x64\x65legations\x12\x30\n\x05nodes\x18\x17 \x03(\x0b\x32\x1a.datanode.api.v2.NodeBasicR\x05nodes\x12H\n\x0fnode_signatures\x18\x18 \x03(\x0b\x32\x1f.vega.commands.v1.NodeSignatureR\x0enodeSignatures\x12\x45\n\x12network_parameters\x18\x19 \x03(\x0b\x32\x16.vega.NetworkParameterR\x11networkParameters\x12@\n\rkey_rotations\x18\x1a \x03(\x0b\x32\x1b.vega.events.v1.KeyRotationR\x0ckeyRotations\x12Y\n\x16\x65thereum_key_rotations\x18\x1b \x03(\x0b\x32#.vega.events.v1.EthereumKeyRotationR\x14\x65thereumKeyRotations\x12\x62\n\x1aprotocol_upgrade_proposals\x18\x1c \x03(\x0b\x32$.vega.events.v1.ProtocolUpgradeEventR\x18protocolUpgradeProposals"\r\n\x0bPingRequest"\x0e\n\x0cPingResponse"\x87\x01\n\tOrderInfo\x12\x1e\n\x04side\x18\x01 \x01(\x0e\x32\n.vega.SideR\x04side\x12\x14\n\x05price\x18\x02 \x01(\tR\x05price\x12\x1c\n\tremaining\x18\x03 \x01(\x04R\tremaining\x12&\n\x0fis_market_order\x18\x04 \x01(\x08R\risMarketOrder"\xe8\x01\n\x17\x45stimatePositionRequest\x12!\n\tmarket_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x08marketId\x12%\n\x0bopen_volume\x18\x02 \x01(\x03\x42\x04\xe2\x41\x01\x02R\nopenVolume\x12\x32\n\x06orders\x18\x03 \x03(\x0b\x32\x1a.datanode.api.v2.OrderInfoR\x06orders\x12\x36\n\x14\x63ollateral_available\x18\x04 \x01(\tH\x00R\x13\x63ollateralAvailable\x88\x01\x01\x42\x17\n\x15_collateral_available"\x9b\x01\n\x18\x45stimatePositionResponse\x12\x37\n\x06margin\x18\x01 \x01(\x0b\x32\x1f.datanode.api.v2.MarginEstimateR\x06margin\x12\x46\n\x0bliquidation\x18\x02 \x01(\x0b\x32$.datanode.api.v2.LiquidationEstimateR\x0bliquidation"t\n\x0eMarginEstimate\x12\x31\n\nworst_case\x18\x01 \x01(\x0b\x32\x12.vega.MarginLevelsR\tworstCase\x12/\n\tbest_case\x18\x02 \x01(\x0b\x32\x12.vega.MarginLevelsR\x08\x62\x65stCase"\x97\x01\n\x13LiquidationEstimate\x12@\n\nworst_case\x18\x01 \x01(\x0b\x32!.datanode.api.v2.LiquidationPriceR\tworstCase\x12>\n\tbest_case\x18\x02 \x01(\x0b\x32!.datanode.api.v2.LiquidationPriceR\x08\x62\x65stCase"\xa2\x01\n\x10LiquidationPrice\x12(\n\x10open_volume_only\x18\x01 \x01(\tR\x0eopenVolumeOnly\x12\x30\n\x14including_buy_orders\x18\x02 \x01(\tR\x12includingBuyOrders\x12\x32\n\x15including_sell_orders\x18\x03 \x01(\tR\x13includingSellOrders*\xaa\x01\n\x10LedgerEntryField\x12"\n\x1eLEDGER_ENTRY_FIELD_UNSPECIFIED\x10\x00\x12&\n"LEDGER_ENTRY_FIELD_ACCOUNT_FROM_ID\x10\x01\x12$\n LEDGER_ENTRY_FIELD_ACCOUNT_TO_ID\x10\x02\x12$\n LEDGER_ENTRY_FIELD_TRANSFER_TYPE\x10\x03*\xb0\x01\n\x0c\x41\x63\x63ountField\x12\x1d\n\x19\x41\x43\x43OUNT_FIELD_UNSPECIFIED\x10\x00\x12\x14\n\x10\x41\x43\x43OUNT_FIELD_ID\x10\x01\x12\x1a\n\x16\x41\x43\x43OUNT_FIELD_PARTY_ID\x10\x02\x12\x1a\n\x16\x41\x43\x43OUNT_FIELD_ASSET_ID\x10\x03\x12\x1b\n\x17\x41\x43\x43OUNT_FIELD_MARKET_ID\x10\x04\x12\x16\n\x12\x41\x43\x43OUNT_FIELD_TYPE\x10\x05*\xad\x01\n\x11TransferDirection\x12"\n\x1eTRANSFER_DIRECTION_UNSPECIFIED\x10\x00\x12$\n TRANSFER_DIRECTION_TRANSFER_FROM\x10\x01\x12"\n\x1eTRANSFER_DIRECTION_TRANSFER_TO\x10\x02\x12*\n&TRANSFER_DIRECTION_TRANSFER_TO_OR_FROM\x10\x03*\xde\x02\n\x05Table\x12\x15\n\x11TABLE_UNSPECIFIED\x10\x00\x12\x12\n\x0eTABLE_BALANCES\x10\x01\x12\x15\n\x11TABLE_CHECKPOINTS\x10\x02\x12\x15\n\x11TABLE_DELEGATIONS\x10\x03\x12\x10\n\x0cTABLE_LEDGER\x10\x04\x12\x10\n\x0cTABLE_ORDERS\x10\x05\x12\x10\n\x0cTABLE_TRADES\x10\x06\x12\x15\n\x11TABLE_MARKET_DATA\x10\x07\x12\x17\n\x13TABLE_MARGIN_LEVELS\x10\x08\x12\x13\n\x0fTABLE_POSITIONS\x10\t\x12\x1e\n\x1aTABLE_LIQUIDITY_PROVISIONS\x10\n\x12\x11\n\rTABLE_MARKETS\x10\x0b\x12\x12\n\x0eTABLE_DEPOSITS\x10\x0c\x12\x15\n\x11TABLE_WITHDRAWALS\x10\r\x12\x10\n\x0cTABLE_BLOCKS\x10\x0e\x12\x11\n\rTABLE_REWARDS\x10\x0f\x32\xf2W\n\x12TradingDataService\x12j\n\x0cListAccounts\x12$.datanode.api.v2.ListAccountsRequest\x1a%.datanode.api.v2.ListAccountsResponse"\r\x92\x41\n\n\x08\x41\x63\x63ounts\x12u\n\x0fObserveAccounts\x12\'.datanode.api.v2.ObserveAccountsRequest\x1a(.datanode.api.v2.ObserveAccountsResponse"\r\x92\x41\n\n\x08\x41\x63\x63ounts0\x01\x12Z\n\x04Info\x12\x1c.datanode.api.v2.InfoRequest\x1a\x1d.datanode.api.v2.InfoResponse"\x15\x92\x41\x12\n\x10Node information\x12\\\n\x08GetOrder\x12 .datanode.api.v2.GetOrderRequest\x1a!.datanode.api.v2.GetOrderResponse"\x0b\x92\x41\x08\n\x06Orders\x12\x62\n\nListOrders\x12".datanode.api.v2.ListOrdersRequest\x1a#.datanode.api.v2.ListOrdersResponse"\x0b\x92\x41\x08\n\x06Orders\x12w\n\x11ListOrderVersions\x12).datanode.api.v2.ListOrderVersionsRequest\x1a*.datanode.api.v2.ListOrderVersionsResponse"\x0b\x92\x41\x08\n\x06Orders\x12m\n\rObserveOrders\x12%.datanode.api.v2.ObserveOrdersRequest\x1a&.datanode.api.v2.ObserveOrdersResponse"\x0b\x92\x41\x08\n\x06Orders0\x01\x12h\n\x0cGetStopOrder\x12$.datanode.api.v2.GetStopOrderRequest\x1a%.datanode.api.v2.GetStopOrderResponse"\x0b\x92\x41\x08\n\x06Orders\x12n\n\x0eListStopOrders\x12&.datanode.api.v2.ListStopOrdersRequest\x1a\'.datanode.api.v2.ListStopOrdersResponse"\x0b\x92\x41\x08\n\x06Orders\x12q\n\rListPositions\x12%.datanode.api.v2.ListPositionsRequest\x1a&.datanode.api.v2.ListPositionsResponse"\x11\x88\x02\x01\x92\x41\x0b\n\tPositions\x12w\n\x10ListAllPositions\x12(.datanode.api.v2.ListAllPositionsRequest\x1a).datanode.api.v2.ListAllPositionsResponse"\x0e\x92\x41\x0b\n\tPositions\x12y\n\x10ObservePositions\x12(.datanode.api.v2.ObservePositionsRequest\x1a).datanode.api.v2.ObservePositionsResponse"\x0e\x92\x41\x0b\n\tPositions0\x01\x12\x7f\n\x11ListLedgerEntries\x12).datanode.api.v2.ListLedgerEntriesRequest\x1a*.datanode.api.v2.ListLedgerEntriesResponse"\x13\x92\x41\x10\n\x0eLedger entries\x12o\n\x13\x45xportLedgerEntries\x12+.datanode.api.v2.ExportLedgerEntriesRequest\x1a\x14.google.api.HttpBody"\x13\x92\x41\x10\n\x0eLedger entries0\x01\x12|\n\x12ListBalanceChanges\x12*.datanode.api.v2.ListBalanceChangesRequest\x1a+.datanode.api.v2.ListBalanceChangesResponse"\r\x92\x41\n\n\x08\x41\x63\x63ounts\x12~\n\x13GetLatestMarketData\x12+.datanode.api.v2.GetLatestMarketDataRequest\x1a,.datanode.api.v2.GetLatestMarketDataResponse"\x0c\x92\x41\t\n\x07Markets\x12\x81\x01\n\x14ListLatestMarketData\x12,.datanode.api.v2.ListLatestMarketDataRequest\x1a-.datanode.api.v2.ListLatestMarketDataResponse"\x0c\x92\x41\t\n\x07Markets\x12\x81\x01\n\x14GetLatestMarketDepth\x12,.datanode.api.v2.GetLatestMarketDepthRequest\x1a-.datanode.api.v2.GetLatestMarketDepthResponse"\x0c\x92\x41\t\n\x07Markets\x12\x80\x01\n\x13ObserveMarketsDepth\x12+.datanode.api.v2.ObserveMarketsDepthRequest\x1a,.datanode.api.v2.ObserveMarketsDepthResponse"\x0c\x92\x41\t\n\x07Markets0\x01\x12\x95\x01\n\x1aObserveMarketsDepthUpdates\x12\x32.datanode.api.v2.ObserveMarketsDepthUpdatesRequest\x1a\x33.datanode.api.v2.ObserveMarketsDepthUpdatesResponse"\x0c\x92\x41\t\n\x07Markets0\x01\x12}\n\x12ObserveMarketsData\x12*.datanode.api.v2.ObserveMarketsDataRequest\x1a+.datanode.api.v2.ObserveMarketsDataResponse"\x0c\x92\x41\t\n\x07Markets0\x01\x12\x8d\x01\n\x18GetMarketDataHistoryByID\x12\x30.datanode.api.v2.GetMarketDataHistoryByIDRequest\x1a\x31.datanode.api.v2.GetMarketDataHistoryByIDResponse"\x0c\x92\x41\t\n\x07Markets\x12n\n\rListTransfers\x12%.datanode.api.v2.ListTransfersRequest\x1a&.datanode.api.v2.ListTransfersResponse"\x0e\x92\x41\x0b\n\tTransfers\x12u\n\x10GetNetworkLimits\x12(.datanode.api.v2.GetNetworkLimitsRequest\x1a).datanode.api.v2.GetNetworkLimitsResponse"\x0c\x92\x41\t\n\x07Network\x12o\n\x0eListCandleData\x12&.datanode.api.v2.ListCandleDataRequest\x1a\'.datanode.api.v2.ListCandleDataResponse"\x0c\x92\x41\t\n\x07\x43\x61ndles\x12z\n\x11ObserveCandleData\x12).datanode.api.v2.ObserveCandleDataRequest\x1a*.datanode.api.v2.ObserveCandleDataResponse"\x0c\x92\x41\t\n\x07\x43\x61ndles0\x01\x12~\n\x13ListCandleIntervals\x12+.datanode.api.v2.ListCandleIntervalsRequest\x1a,.datanode.api.v2.ListCandleIntervalsResponse"\x0c\x92\x41\t\n\x07\x43\x61ndles\x12\x63\n\tListVotes\x12!.datanode.api.v2.ListVotesRequest\x1a".datanode.api.v2.ListVotesResponse"\x0f\x92\x41\x0c\n\nGovernance\x12n\n\x0cObserveVotes\x12$.datanode.api.v2.ObserveVotesRequest\x1a%.datanode.api.v2.ObserveVotesResponse"\x0f\x92\x41\x0c\n\nGovernance0\x01\x12\xb3\x01\n#ListERC20MultiSigSignerAddedBundles\x12;.datanode.api.v2.ListERC20MultiSigSignerAddedBundlesRequest\x1a<.datanode.api.v2.ListERC20MultiSigSignerAddedBundlesResponse"\x11\x92\x41\x0e\n\x0c\x45RC20 bridge\x12\xb9\x01\n%ListERC20MultiSigSignerRemovedBundles\x12=.datanode.api.v2.ListERC20MultiSigSignerRemovedBundlesRequest\x1a>.datanode.api.v2.ListERC20MultiSigSignerRemovedBundlesResponse"\x11\x92\x41\x0e\n\x0c\x45RC20 bridge\x12\x8f\x01\n\x17GetERC20ListAssetBundle\x12/.datanode.api.v2.GetERC20ListAssetBundleRequest\x1a\x30.datanode.api.v2.GetERC20ListAssetBundleResponse"\x11\x92\x41\x0e\n\x0c\x45RC20 bridge\x12\x9e\x01\n\x1cGetERC20SetAssetLimitsBundle\x12\x34.datanode.api.v2.GetERC20SetAssetLimitsBundleRequest\x1a\x35.datanode.api.v2.GetERC20SetAssetLimitsBundleResponse"\x11\x92\x41\x0e\n\x0c\x45RC20 bridge\x12\x98\x01\n\x1aGetERC20WithdrawalApproval\x12\x32.datanode.api.v2.GetERC20WithdrawalApprovalRequest\x1a\x33.datanode.api.v2.GetERC20WithdrawalApprovalResponse"\x11\x92\x41\x0e\n\x0c\x45RC20 bridge\x12h\n\x0cGetLastTrade\x12$.datanode.api.v2.GetLastTradeRequest\x1a%.datanode.api.v2.GetLastTradeResponse"\x0b\x92\x41\x08\n\x06Trades\x12\x62\n\nListTrades\x12".datanode.api.v2.ListTradesRequest\x1a#.datanode.api.v2.ListTradesResponse"\x0b\x92\x41\x08\n\x06Trades\x12m\n\rObserveTrades\x12%.datanode.api.v2.ObserveTradesRequest\x1a&.datanode.api.v2.ObserveTradesResponse"\x0b\x92\x41\x08\n\x06Trades0\x01\x12q\n\rGetOracleSpec\x12%.datanode.api.v2.GetOracleSpecRequest\x1a&.datanode.api.v2.GetOracleSpecResponse"\x11\x92\x41\x0e\n\x0c\x44\x61ta sources\x12w\n\x0fListOracleSpecs\x12\'.datanode.api.v2.ListOracleSpecsRequest\x1a(.datanode.api.v2.ListOracleSpecsResponse"\x11\x92\x41\x0e\n\x0c\x44\x61ta sources\x12t\n\x0eListOracleData\x12&.datanode.api.v2.ListOracleDataRequest\x1a\'.datanode.api.v2.ListOracleDataResponse"\x11\x92\x41\x0e\n\x0c\x44\x61ta sources\x12`\n\tGetMarket\x12!.datanode.api.v2.GetMarketRequest\x1a".datanode.api.v2.GetMarketResponse"\x0c\x92\x41\t\n\x07Markets\x12\x66\n\x0bListMarkets\x12#.datanode.api.v2.ListMarketsRequest\x1a$.datanode.api.v2.ListMarketsResponse"\x0c\x92\x41\t\n\x07Markets\x12\x81\x01\n\x14ListSuccessorMarkets\x12,.datanode.api.v2.ListSuccessorMarketsRequest\x1a-.datanode.api.v2.ListSuccessorMarketsResponse"\x0c\x92\x41\t\n\x07Markets\x12]\n\x08GetParty\x12 .datanode.api.v2.GetPartyRequest\x1a!.datanode.api.v2.GetPartyResponse"\x0c\x92\x41\t\n\x07Parties\x12\x66\n\x0bListParties\x12#.datanode.api.v2.ListPartiesRequest\x1a$.datanode.api.v2.ListPartiesResponse"\x0c\x92\x41\t\n\x07Parties\x12{\n\x10ListMarginLevels\x12(.datanode.api.v2.ListMarginLevelsRequest\x1a).datanode.api.v2.ListMarginLevelsResponse"\x12\x92\x41\x0f\n\rMargin levels\x12\x86\x01\n\x13ObserveMarginLevels\x12+.datanode.api.v2.ObserveMarginLevelsRequest\x1a,.datanode.api.v2.ObserveMarginLevelsResponse"\x12\x92\x41\x0f\n\rMargin levels0\x01\x12\x66\n\x0bListRewards\x12#.datanode.api.v2.ListRewardsRequest\x1a$.datanode.api.v2.ListRewardsResponse"\x0c\x92\x41\t\n\x07Rewards\x12~\n\x13ListRewardSummaries\x12+.datanode.api.v2.ListRewardSummariesRequest\x1a,.datanode.api.v2.ListRewardSummariesResponse"\x0c\x92\x41\t\n\x07Rewards\x12\x8d\x01\n\x18ListEpochRewardSummaries\x12\x30.datanode.api.v2.ListEpochRewardSummariesRequest\x1a\x31.datanode.api.v2.ListEpochRewardSummariesResponse"\x0c\x92\x41\t\n\x07Rewards\x12\x62\n\nGetDeposit\x12".datanode.api.v2.GetDepositRequest\x1a#.datanode.api.v2.GetDepositResponse"\x0b\x92\x41\x08\n\x06\x41ssets\x12h\n\x0cListDeposits\x12$.datanode.api.v2.ListDepositsRequest\x1a%.datanode.api.v2.ListDepositsResponse"\x0b\x92\x41\x08\n\x06\x41ssets\x12k\n\rGetWithdrawal\x12%.datanode.api.v2.GetWithdrawalRequest\x1a&.datanode.api.v2.GetWithdrawalResponse"\x0b\x92\x41\x08\n\x06\x41ssets\x12q\n\x0fListWithdrawals\x12\'.datanode.api.v2.ListWithdrawalsRequest\x1a(.datanode.api.v2.ListWithdrawalsResponse"\x0b\x92\x41\x08\n\x06\x41ssets\x12\\\n\x08GetAsset\x12 .datanode.api.v2.GetAssetRequest\x1a!.datanode.api.v2.GetAssetResponse"\x0b\x92\x41\x08\n\x06\x41ssets\x12\x62\n\nListAssets\x12".datanode.api.v2.ListAssetsRequest\x1a#.datanode.api.v2.ListAssetsResponse"\x0b\x92\x41\x08\n\x06\x41ssets\x12\x97\x01\n\x17ListLiquidityProvisions\x12/.datanode.api.v2.ListLiquidityProvisionsRequest\x1a\x30.datanode.api.v2.ListLiquidityProvisionsResponse"\x19\x92\x41\x16\n\x14Liquidity provisions\x12\xa2\x01\n\x1aObserveLiquidityProvisions\x12\x32.datanode.api.v2.ObserveLiquidityProvisionsRequest\x1a\x33.datanode.api.v2.ObserveLiquidityProvisionsResponse"\x19\x92\x41\x16\n\x14Liquidity provisions0\x01\x12{\n\x11GetGovernanceData\x12).datanode.api.v2.GetGovernanceDataRequest\x1a*.datanode.api.v2.GetGovernanceDataResponse"\x0f\x92\x41\x0c\n\nGovernance\x12~\n\x12ListGovernanceData\x12*.datanode.api.v2.ListGovernanceDataRequest\x1a+.datanode.api.v2.ListGovernanceDataResponse"\x0f\x92\x41\x0c\n\nGovernance\x12}\n\x11ObserveGovernance\x12).datanode.api.v2.ObserveGovernanceRequest\x1a*.datanode.api.v2.ObserveGovernanceResponse"\x0f\x92\x41\x0c\n\nGovernance0\x01\x12r\n\x0fListDelegations\x12\'.datanode.api.v2.ListDelegationsRequest\x1a(.datanode.api.v2.ListDelegationsResponse"\x0c\x92\x41\t\n\x07Network\x12o\n\x0eGetNetworkData\x12&.datanode.api.v2.GetNetworkDataRequest\x1a\'.datanode.api.v2.GetNetworkDataResponse"\x0c\x92\x41\t\n\x07Network\x12Z\n\x07GetNode\x12\x1f.datanode.api.v2.GetNodeRequest\x1a .datanode.api.v2.GetNodeResponse"\x0c\x92\x41\t\n\x07Network\x12`\n\tListNodes\x12!.datanode.api.v2.ListNodesRequest\x1a".datanode.api.v2.ListNodesResponse"\x0c\x92\x41\t\n\x07Network\x12\x80\x01\n\x12ListNodeSignatures\x12*.datanode.api.v2.ListNodeSignaturesRequest\x1a+.datanode.api.v2.ListNodeSignaturesResponse"\x11\x92\x41\x0e\n\x0c\x45RC20 bridge\x12]\n\x08GetEpoch\x12 .datanode.api.v2.GetEpochRequest\x1a!.datanode.api.v2.GetEpochResponse"\x0c\x92\x41\t\n\x07Network\x12\x65\n\x0b\x45stimateFee\x12#.datanode.api.v2.EstimateFeeRequest\x1a$.datanode.api.v2.EstimateFeeResponse"\x0b\x92\x41\x08\n\x06Orders\x12n\n\x0e\x45stimateMargin\x12&.datanode.api.v2.EstimateMarginRequest\x1a\'.datanode.api.v2.EstimateMarginResponse"\x0b\x92\x41\x08\n\x06Orders\x12w\n\x10\x45stimatePosition\x12(.datanode.api.v2.EstimatePositionRequest\x1a).datanode.api.v2.EstimatePositionResponse"\x0e\x92\x41\x0b\n\tPositions\x12\x84\x01\n\x15ListNetworkParameters\x12-.datanode.api.v2.ListNetworkParametersRequest\x1a..datanode.api.v2.ListNetworkParametersResponse"\x0c\x92\x41\t\n\x07Network\x12~\n\x13GetNetworkParameter\x12+.datanode.api.v2.GetNetworkParameterRequest\x1a,.datanode.api.v2.GetNetworkParameterResponse"\x0c\x92\x41\t\n\x07Network\x12r\n\x0fListCheckpoints\x12\'.datanode.api.v2.ListCheckpointsRequest\x1a(.datanode.api.v2.ListCheckpointsResponse"\x0c\x92\x41\t\n\x07Network\x12]\n\x08GetStake\x12 .datanode.api.v2.GetStakeRequest\x1a!.datanode.api.v2.GetStakeResponse"\x0c\x92\x41\t\n\x07Network\x12o\n\x0eGetRiskFactors\x12&.datanode.api.v2.GetRiskFactorsRequest\x1a\'.datanode.api.v2.GetRiskFactorsResponse"\x0c\x92\x41\t\n\x07Markets\x12u\n\x0fObserveEventBus\x12\'.datanode.api.v2.ObserveEventBusRequest\x1a(.datanode.api.v2.ObserveEventBusResponse"\x0b\x92\x41\x08\n\x06\x45vents(\x01\x30\x01\x12\x92\x01\n\x16ObserveLedgerMovements\x12..datanode.api.v2.ObserveLedgerMovementsRequest\x1a/.datanode.api.v2.ObserveLedgerMovementsResponse"\x15\x92\x41\x12\n\x10Ledger movements0\x01\x12u\n\x10ListKeyRotations\x12(.datanode.api.v2.ListKeyRotationsRequest\x1a).datanode.api.v2.ListKeyRotationsResponse"\x0c\x92\x41\t\n\x07Network\x12\x8d\x01\n\x18ListEthereumKeyRotations\x12\x30.datanode.api.v2.ListEthereumKeyRotationsRequest\x1a\x31.datanode.api.v2.ListEthereumKeyRotationsResponse"\x0c\x92\x41\t\n\x07Network\x12\x66\n\x0bGetVegaTime\x12#.datanode.api.v2.GetVegaTimeRequest\x1a$.datanode.api.v2.GetVegaTimeResponse"\x0c\x92\x41\t\n\x07Network\x12\x8d\x01\n\x18GetProtocolUpgradeStatus\x12\x30.datanode.api.v2.GetProtocolUpgradeStatusRequest\x1a\x31.datanode.api.v2.GetProtocolUpgradeStatusResponse"\x0c\x92\x41\t\n\x07Network\x12\x99\x01\n\x1cListProtocolUpgradeProposals\x12\x34.datanode.api.v2.ListProtocolUpgradeProposalsRequest\x1a\x35.datanode.api.v2.ListProtocolUpgradeProposalsResponse"\x0c\x92\x41\t\n\x07Network\x12x\n\x11ListCoreSnapshots\x12).datanode.api.v2.ListCoreSnapshotsRequest\x1a*.datanode.api.v2.ListCoreSnapshotsResponse"\x0c\x92\x41\t\n\x07Network\x12\xb3\x01\n"GetMostRecentNetworkHistorySegment\x12:.datanode.api.v2.GetMostRecentNetworkHistorySegmentRequest\x1a;.datanode.api.v2.GetMostRecentNetworkHistorySegmentResponse"\x14\x92\x41\x11\n\x0fNetwork history\x12\xa4\x01\n\x1dListAllNetworkHistorySegments\x12\x35.datanode.api.v2.ListAllNetworkHistorySegmentsRequest\x1a\x36.datanode.api.v2.ListAllNetworkHistorySegmentsResponse"\x14\x92\x41\x11\n\x0fNetwork history\x12\xb9\x01\n$GetActiveNetworkHistoryPeerAddresses\x12<.datanode.api.v2.GetActiveNetworkHistoryPeerAddressesRequest\x1a=.datanode.api.v2.GetActiveNetworkHistoryPeerAddressesResponse"\x14\x92\x41\x11\n\x0fNetwork history\x12\x92\x01\n\x17GetNetworkHistoryStatus\x12/.datanode.api.v2.GetNetworkHistoryStatusRequest\x1a\x30.datanode.api.v2.GetNetworkHistoryStatusResponse"\x14\x92\x41\x11\n\x0fNetwork history\x12\xaa\x01\n\x1fGetNetworkHistoryBootstrapPeers\x12\x37.datanode.api.v2.GetNetworkHistoryBootstrapPeersRequest\x1a\x38.datanode.api.v2.GetNetworkHistoryBootstrapPeersResponse"\x14\x92\x41\x11\n\x0fNetwork history\x12j\n\x0cListEntities\x12$.datanode.api.v2.ListEntitiesRequest\x1a%.datanode.api.v2.ListEntitiesResponse"\r\x92\x41\n\n\x08\x45xplorer\x12r\n\x14\x45xportNetworkHistory\x12,.datanode.api.v2.ExportNetworkHistoryRequest\x1a\x14.google.api.HttpBody"\x14\x92\x41\x11\n\x0fNetwork history0\x01\x12N\n\x04Ping\x12\x1c.datanode.api.v2.PingRequest\x1a\x1d.datanode.api.v2.PingResponse"\t\x92\x41\x06\n\x04MiscB\xc6\x01Z1code.vegaprotocol.io/vega/protos/data-node/api/v2\x92\x41\x8f\x01\x12\x1e\n\x13Vega data node APIs2\x07v0.72.6\x1a\x1chttps://api.testnet.vega.xyz*\x02\x01\x02\x32\x10\x61pplication/jsonR9\n\x03\x35\x30\x30\x12\x32\n\x18\x41n internal server error\x12\x16\n\x14\x1a\x12.google.rpc.Statusb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "data_node.api.v2.trading_data_pb2", _globals
)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b"Z1code.vegaprotocol.io/vega/protos/data-node/api/v2\222A\217\001\022\036\n\023Vega data node APIs2\007v0.72.6\032\034https://api.testnet.vega.xyz*\002\001\0022\020application/jsonR9\n\003500\0222\n\030An internal server error\022\026\n\024\032\022.google.rpc.Status"
    _GETORDERREQUEST.fields_by_name["order_id"]._options = None
    _GETORDERREQUEST.fields_by_name["order_id"]._serialized_options = b"\342A\001\002"
    _LISTORDERVERSIONSREQUEST.fields_by_name["order_id"]._options = None
    _LISTORDERVERSIONSREQUEST.fields_by_name[
        "order_id"
    ]._serialized_options = b"\342A\001\002"
    _GETSTOPORDERREQUEST.fields_by_name["order_id"]._options = None
    _GETSTOPORDERREQUEST.fields_by_name[
        "order_id"
    ]._serialized_options = b"\342A\001\002"
    _LISTPOSITIONSREQUEST._options = None
    _LISTPOSITIONSREQUEST._serialized_options = b"\030\001"
    _LISTPOSITIONSRESPONSE._options = None
    _LISTPOSITIONSRESPONSE._serialized_options = b"\030\001"
    _EXPORTLEDGERENTRIESREQUEST.fields_by_name["party_id"]._options = None
    _EXPORTLEDGERENTRIESREQUEST.fields_by_name[
        "party_id"
    ]._serialized_options = b"\342A\001\002"
    _EXPORTLEDGERENTRIESREQUEST.fields_by_name["asset_id"]._options = None
    _EXPORTLEDGERENTRIESREQUEST.fields_by_name[
        "asset_id"
    ]._serialized_options = b"\342A\001\002"
    _GETLATESTMARKETDEPTHREQUEST.fields_by_name["market_id"]._options = None
    _GETLATESTMARKETDEPTHREQUEST.fields_by_name[
        "market_id"
    ]._serialized_options = b"\342A\001\002"
    _GETLATESTMARKETDATAREQUEST.fields_by_name["market_id"]._options = None
    _GETLATESTMARKETDATAREQUEST.fields_by_name[
        "market_id"
    ]._serialized_options = b"\342A\001\002"
    _GETMARKETDATAHISTORYBYIDREQUEST.fields_by_name["market_id"]._options = None
    _GETMARKETDATAHISTORYBYIDREQUEST.fields_by_name[
        "market_id"
    ]._serialized_options = b"\342A\001\002"
    _LISTCANDLEINTERVALSREQUEST.fields_by_name["market_id"]._options = None
    _LISTCANDLEINTERVALSREQUEST.fields_by_name[
        "market_id"
    ]._serialized_options = b"\342A\001\002"
    _OBSERVECANDLEDATAREQUEST.fields_by_name["candle_id"]._options = None
    _OBSERVECANDLEDATAREQUEST.fields_by_name[
        "candle_id"
    ]._serialized_options = b"\342A\001\002"
    _LISTCANDLEDATAREQUEST.fields_by_name["candle_id"]._options = None
    _LISTCANDLEDATAREQUEST.fields_by_name[
        "candle_id"
    ]._serialized_options = b"\342A\001\002"
    _GETERC20LISTASSETBUNDLEREQUEST.fields_by_name["asset_id"]._options = None
    _GETERC20LISTASSETBUNDLEREQUEST.fields_by_name[
        "asset_id"
    ]._serialized_options = b"\342A\001\002"
    _GETERC20SETASSETLIMITSBUNDLEREQUEST.fields_by_name["proposal_id"]._options = None
    _GETERC20SETASSETLIMITSBUNDLEREQUEST.fields_by_name[
        "proposal_id"
    ]._serialized_options = b"\342A\001\002"
    _GETERC20WITHDRAWALAPPROVALREQUEST.fields_by_name["withdrawal_id"]._options = None
    _GETERC20WITHDRAWALAPPROVALREQUEST.fields_by_name[
        "withdrawal_id"
    ]._serialized_options = b"\342A\001\002"
    _GETLASTTRADEREQUEST.fields_by_name["market_id"]._options = None
    _GETLASTTRADEREQUEST.fields_by_name[
        "market_id"
    ]._serialized_options = b"\342A\001\002"
    _GETORACLESPECREQUEST.fields_by_name["oracle_spec_id"]._options = None
    _GETORACLESPECREQUEST.fields_by_name[
        "oracle_spec_id"
    ]._serialized_options = b"\342A\001\002"
    _GETMARKETREQUEST.fields_by_name["market_id"]._options = None
    _GETMARKETREQUEST.fields_by_name["market_id"]._serialized_options = b"\342A\001\002"
    _LISTSUCCESSORMARKETSREQUEST.fields_by_name["market_id"]._options = None
    _LISTSUCCESSORMARKETSREQUEST.fields_by_name[
        "market_id"
    ]._serialized_options = b"\342A\001\002"
    _GETPARTYREQUEST.fields_by_name["party_id"]._options = None
    _GETPARTYREQUEST.fields_by_name["party_id"]._serialized_options = b"\342A\001\002"
    _GETDEPOSITREQUEST.fields_by_name["id"]._options = None
    _GETDEPOSITREQUEST.fields_by_name["id"]._serialized_options = b"\342A\001\002"
    _GETWITHDRAWALREQUEST.fields_by_name["id"]._options = None
    _GETWITHDRAWALREQUEST.fields_by_name["id"]._serialized_options = b"\342A\001\002"
    _GETASSETREQUEST.fields_by_name["asset_id"]._options = None
    _GETASSETREQUEST.fields_by_name["asset_id"]._serialized_options = b"\342A\001\002"
    _GETNODEREQUEST.fields_by_name["id"]._options = None
    _GETNODEREQUEST.fields_by_name["id"]._serialized_options = b"\342A\001\002"
    _LISTNODESIGNATURESREQUEST.fields_by_name["id"]._options = None
    _LISTNODESIGNATURESREQUEST.fields_by_name[
        "id"
    ]._serialized_options = b"\342A\001\002"
    _ESTIMATEFEEREQUEST.fields_by_name["market_id"]._options = None
    _ESTIMATEFEEREQUEST.fields_by_name[
        "market_id"
    ]._serialized_options = b"\342A\001\002"
    _ESTIMATEFEEREQUEST.fields_by_name["price"]._options = None
    _ESTIMATEFEEREQUEST.fields_by_name["price"]._serialized_options = b"\342A\001\002"
    _ESTIMATEFEEREQUEST.fields_by_name["size"]._options = None
    _ESTIMATEFEEREQUEST.fields_by_name["size"]._serialized_options = b"\342A\001\002"
    _ESTIMATEMARGINREQUEST.fields_by_name["market_id"]._options = None
    _ESTIMATEMARGINREQUEST.fields_by_name[
        "market_id"
    ]._serialized_options = b"\342A\001\002"
    _ESTIMATEMARGINREQUEST.fields_by_name["party_id"]._options = None
    _ESTIMATEMARGINREQUEST.fields_by_name[
        "party_id"
    ]._serialized_options = b"\342A\001\002"
    _ESTIMATEMARGINREQUEST.fields_by_name["side"]._options = None
    _ESTIMATEMARGINREQUEST.fields_by_name["side"]._serialized_options = b"\342A\001\002"
    _ESTIMATEMARGINREQUEST.fields_by_name["type"]._options = None
    _ESTIMATEMARGINREQUEST.fields_by_name["type"]._serialized_options = b"\342A\001\002"
    _ESTIMATEMARGINREQUEST.fields_by_name["size"]._options = None
    _ESTIMATEMARGINREQUEST.fields_by_name["size"]._serialized_options = b"\342A\001\002"
    _ESTIMATEMARGINREQUEST.fields_by_name["price"]._options = None
    _ESTIMATEMARGINREQUEST.fields_by_name[
        "price"
    ]._serialized_options = b"\342A\001\002"
    _ESTIMATEMARGINREQUEST._options = None
    _ESTIMATEMARGINREQUEST._serialized_options = b"\030\001"
    _ESTIMATEMARGINRESPONSE._options = None
    _ESTIMATEMARGINRESPONSE._serialized_options = b"\030\001"
    _GETNETWORKPARAMETERREQUEST.fields_by_name["key"]._options = None
    _GETNETWORKPARAMETERREQUEST.fields_by_name[
        "key"
    ]._serialized_options = b"\342A\001\002"
    _GETSTAKEREQUEST.fields_by_name["party_id"]._options = None
    _GETSTAKEREQUEST.fields_by_name["party_id"]._serialized_options = b"\342A\001\002"
    _GETRISKFACTORSREQUEST.fields_by_name["market_id"]._options = None
    _GETRISKFACTORSREQUEST.fields_by_name[
        "market_id"
    ]._serialized_options = b"\342A\001\002"
    _LISTENTITIESREQUEST.fields_by_name["transaction_hash"]._options = None
    _LISTENTITIESREQUEST.fields_by_name[
        "transaction_hash"
    ]._serialized_options = b"\342A\001\002"
    _ESTIMATEPOSITIONREQUEST.fields_by_name["market_id"]._options = None
    _ESTIMATEPOSITIONREQUEST.fields_by_name[
        "market_id"
    ]._serialized_options = b"\342A\001\002"
    _ESTIMATEPOSITIONREQUEST.fields_by_name["open_volume"]._options = None
    _ESTIMATEPOSITIONREQUEST.fields_by_name[
        "open_volume"
    ]._serialized_options = b"\342A\001\002"
    _TRADINGDATASERVICE.methods_by_name["ListAccounts"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListAccounts"
    ]._serialized_options = b"\222A\n\n\010Accounts"
    _TRADINGDATASERVICE.methods_by_name["ObserveAccounts"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ObserveAccounts"
    ]._serialized_options = b"\222A\n\n\010Accounts"
    _TRADINGDATASERVICE.methods_by_name["Info"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "Info"
    ]._serialized_options = b"\222A\022\n\020Node information"
    _TRADINGDATASERVICE.methods_by_name["GetOrder"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "GetOrder"
    ]._serialized_options = b"\222A\010\n\006Orders"
    _TRADINGDATASERVICE.methods_by_name["ListOrders"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListOrders"
    ]._serialized_options = b"\222A\010\n\006Orders"
    _TRADINGDATASERVICE.methods_by_name["ListOrderVersions"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListOrderVersions"
    ]._serialized_options = b"\222A\010\n\006Orders"
    _TRADINGDATASERVICE.methods_by_name["ObserveOrders"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ObserveOrders"
    ]._serialized_options = b"\222A\010\n\006Orders"
    _TRADINGDATASERVICE.methods_by_name["GetStopOrder"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "GetStopOrder"
    ]._serialized_options = b"\222A\010\n\006Orders"
    _TRADINGDATASERVICE.methods_by_name["ListStopOrders"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListStopOrders"
    ]._serialized_options = b"\222A\010\n\006Orders"
    _TRADINGDATASERVICE.methods_by_name["ListPositions"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListPositions"
    ]._serialized_options = b"\210\002\001\222A\013\n\tPositions"
    _TRADINGDATASERVICE.methods_by_name["ListAllPositions"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListAllPositions"
    ]._serialized_options = b"\222A\013\n\tPositions"
    _TRADINGDATASERVICE.methods_by_name["ObservePositions"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ObservePositions"
    ]._serialized_options = b"\222A\013\n\tPositions"
    _TRADINGDATASERVICE.methods_by_name["ListLedgerEntries"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListLedgerEntries"
    ]._serialized_options = b"\222A\020\n\016Ledger entries"
    _TRADINGDATASERVICE.methods_by_name["ExportLedgerEntries"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ExportLedgerEntries"
    ]._serialized_options = b"\222A\020\n\016Ledger entries"
    _TRADINGDATASERVICE.methods_by_name["ListBalanceChanges"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListBalanceChanges"
    ]._serialized_options = b"\222A\n\n\010Accounts"
    _TRADINGDATASERVICE.methods_by_name["GetLatestMarketData"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "GetLatestMarketData"
    ]._serialized_options = b"\222A\t\n\007Markets"
    _TRADINGDATASERVICE.methods_by_name["ListLatestMarketData"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListLatestMarketData"
    ]._serialized_options = b"\222A\t\n\007Markets"
    _TRADINGDATASERVICE.methods_by_name["GetLatestMarketDepth"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "GetLatestMarketDepth"
    ]._serialized_options = b"\222A\t\n\007Markets"
    _TRADINGDATASERVICE.methods_by_name["ObserveMarketsDepth"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ObserveMarketsDepth"
    ]._serialized_options = b"\222A\t\n\007Markets"
    _TRADINGDATASERVICE.methods_by_name["ObserveMarketsDepthUpdates"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ObserveMarketsDepthUpdates"
    ]._serialized_options = b"\222A\t\n\007Markets"
    _TRADINGDATASERVICE.methods_by_name["ObserveMarketsData"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ObserveMarketsData"
    ]._serialized_options = b"\222A\t\n\007Markets"
    _TRADINGDATASERVICE.methods_by_name["GetMarketDataHistoryByID"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "GetMarketDataHistoryByID"
    ]._serialized_options = b"\222A\t\n\007Markets"
    _TRADINGDATASERVICE.methods_by_name["ListTransfers"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListTransfers"
    ]._serialized_options = b"\222A\013\n\tTransfers"
    _TRADINGDATASERVICE.methods_by_name["GetNetworkLimits"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "GetNetworkLimits"
    ]._serialized_options = b"\222A\t\n\007Network"
    _TRADINGDATASERVICE.methods_by_name["ListCandleData"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListCandleData"
    ]._serialized_options = b"\222A\t\n\007Candles"
    _TRADINGDATASERVICE.methods_by_name["ObserveCandleData"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ObserveCandleData"
    ]._serialized_options = b"\222A\t\n\007Candles"
    _TRADINGDATASERVICE.methods_by_name["ListCandleIntervals"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListCandleIntervals"
    ]._serialized_options = b"\222A\t\n\007Candles"
    _TRADINGDATASERVICE.methods_by_name["ListVotes"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListVotes"
    ]._serialized_options = b"\222A\014\n\nGovernance"
    _TRADINGDATASERVICE.methods_by_name["ObserveVotes"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ObserveVotes"
    ]._serialized_options = b"\222A\014\n\nGovernance"
    _TRADINGDATASERVICE.methods_by_name[
        "ListERC20MultiSigSignerAddedBundles"
    ]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListERC20MultiSigSignerAddedBundles"
    ]._serialized_options = b"\222A\016\n\014ERC20 bridge"
    _TRADINGDATASERVICE.methods_by_name[
        "ListERC20MultiSigSignerRemovedBundles"
    ]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListERC20MultiSigSignerRemovedBundles"
    ]._serialized_options = b"\222A\016\n\014ERC20 bridge"
    _TRADINGDATASERVICE.methods_by_name["GetERC20ListAssetBundle"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "GetERC20ListAssetBundle"
    ]._serialized_options = b"\222A\016\n\014ERC20 bridge"
    _TRADINGDATASERVICE.methods_by_name["GetERC20SetAssetLimitsBundle"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "GetERC20SetAssetLimitsBundle"
    ]._serialized_options = b"\222A\016\n\014ERC20 bridge"
    _TRADINGDATASERVICE.methods_by_name["GetERC20WithdrawalApproval"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "GetERC20WithdrawalApproval"
    ]._serialized_options = b"\222A\016\n\014ERC20 bridge"
    _TRADINGDATASERVICE.methods_by_name["GetLastTrade"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "GetLastTrade"
    ]._serialized_options = b"\222A\010\n\006Trades"
    _TRADINGDATASERVICE.methods_by_name["ListTrades"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListTrades"
    ]._serialized_options = b"\222A\010\n\006Trades"
    _TRADINGDATASERVICE.methods_by_name["ObserveTrades"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ObserveTrades"
    ]._serialized_options = b"\222A\010\n\006Trades"
    _TRADINGDATASERVICE.methods_by_name["GetOracleSpec"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "GetOracleSpec"
    ]._serialized_options = b"\222A\016\n\014Data sources"
    _TRADINGDATASERVICE.methods_by_name["ListOracleSpecs"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListOracleSpecs"
    ]._serialized_options = b"\222A\016\n\014Data sources"
    _TRADINGDATASERVICE.methods_by_name["ListOracleData"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListOracleData"
    ]._serialized_options = b"\222A\016\n\014Data sources"
    _TRADINGDATASERVICE.methods_by_name["GetMarket"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "GetMarket"
    ]._serialized_options = b"\222A\t\n\007Markets"
    _TRADINGDATASERVICE.methods_by_name["ListMarkets"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListMarkets"
    ]._serialized_options = b"\222A\t\n\007Markets"
    _TRADINGDATASERVICE.methods_by_name["ListSuccessorMarkets"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListSuccessorMarkets"
    ]._serialized_options = b"\222A\t\n\007Markets"
    _TRADINGDATASERVICE.methods_by_name["GetParty"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "GetParty"
    ]._serialized_options = b"\222A\t\n\007Parties"
    _TRADINGDATASERVICE.methods_by_name["ListParties"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListParties"
    ]._serialized_options = b"\222A\t\n\007Parties"
    _TRADINGDATASERVICE.methods_by_name["ListMarginLevels"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListMarginLevels"
    ]._serialized_options = b"\222A\017\n\rMargin levels"
    _TRADINGDATASERVICE.methods_by_name["ObserveMarginLevels"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ObserveMarginLevels"
    ]._serialized_options = b"\222A\017\n\rMargin levels"
    _TRADINGDATASERVICE.methods_by_name["ListRewards"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListRewards"
    ]._serialized_options = b"\222A\t\n\007Rewards"
    _TRADINGDATASERVICE.methods_by_name["ListRewardSummaries"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListRewardSummaries"
    ]._serialized_options = b"\222A\t\n\007Rewards"
    _TRADINGDATASERVICE.methods_by_name["ListEpochRewardSummaries"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListEpochRewardSummaries"
    ]._serialized_options = b"\222A\t\n\007Rewards"
    _TRADINGDATASERVICE.methods_by_name["GetDeposit"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "GetDeposit"
    ]._serialized_options = b"\222A\010\n\006Assets"
    _TRADINGDATASERVICE.methods_by_name["ListDeposits"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListDeposits"
    ]._serialized_options = b"\222A\010\n\006Assets"
    _TRADINGDATASERVICE.methods_by_name["GetWithdrawal"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "GetWithdrawal"
    ]._serialized_options = b"\222A\010\n\006Assets"
    _TRADINGDATASERVICE.methods_by_name["ListWithdrawals"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListWithdrawals"
    ]._serialized_options = b"\222A\010\n\006Assets"
    _TRADINGDATASERVICE.methods_by_name["GetAsset"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "GetAsset"
    ]._serialized_options = b"\222A\010\n\006Assets"
    _TRADINGDATASERVICE.methods_by_name["ListAssets"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListAssets"
    ]._serialized_options = b"\222A\010\n\006Assets"
    _TRADINGDATASERVICE.methods_by_name["ListLiquidityProvisions"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListLiquidityProvisions"
    ]._serialized_options = b"\222A\026\n\024Liquidity provisions"
    _TRADINGDATASERVICE.methods_by_name["ObserveLiquidityProvisions"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ObserveLiquidityProvisions"
    ]._serialized_options = b"\222A\026\n\024Liquidity provisions"
    _TRADINGDATASERVICE.methods_by_name["GetGovernanceData"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "GetGovernanceData"
    ]._serialized_options = b"\222A\014\n\nGovernance"
    _TRADINGDATASERVICE.methods_by_name["ListGovernanceData"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListGovernanceData"
    ]._serialized_options = b"\222A\014\n\nGovernance"
    _TRADINGDATASERVICE.methods_by_name["ObserveGovernance"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ObserveGovernance"
    ]._serialized_options = b"\222A\014\n\nGovernance"
    _TRADINGDATASERVICE.methods_by_name["ListDelegations"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListDelegations"
    ]._serialized_options = b"\222A\t\n\007Network"
    _TRADINGDATASERVICE.methods_by_name["GetNetworkData"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "GetNetworkData"
    ]._serialized_options = b"\222A\t\n\007Network"
    _TRADINGDATASERVICE.methods_by_name["GetNode"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "GetNode"
    ]._serialized_options = b"\222A\t\n\007Network"
    _TRADINGDATASERVICE.methods_by_name["ListNodes"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListNodes"
    ]._serialized_options = b"\222A\t\n\007Network"
    _TRADINGDATASERVICE.methods_by_name["ListNodeSignatures"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListNodeSignatures"
    ]._serialized_options = b"\222A\016\n\014ERC20 bridge"
    _TRADINGDATASERVICE.methods_by_name["GetEpoch"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "GetEpoch"
    ]._serialized_options = b"\222A\t\n\007Network"
    _TRADINGDATASERVICE.methods_by_name["EstimateFee"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "EstimateFee"
    ]._serialized_options = b"\222A\010\n\006Orders"
    _TRADINGDATASERVICE.methods_by_name["EstimateMargin"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "EstimateMargin"
    ]._serialized_options = b"\222A\010\n\006Orders"
    _TRADINGDATASERVICE.methods_by_name["EstimatePosition"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "EstimatePosition"
    ]._serialized_options = b"\222A\013\n\tPositions"
    _TRADINGDATASERVICE.methods_by_name["ListNetworkParameters"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListNetworkParameters"
    ]._serialized_options = b"\222A\t\n\007Network"
    _TRADINGDATASERVICE.methods_by_name["GetNetworkParameter"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "GetNetworkParameter"
    ]._serialized_options = b"\222A\t\n\007Network"
    _TRADINGDATASERVICE.methods_by_name["ListCheckpoints"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListCheckpoints"
    ]._serialized_options = b"\222A\t\n\007Network"
    _TRADINGDATASERVICE.methods_by_name["GetStake"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "GetStake"
    ]._serialized_options = b"\222A\t\n\007Network"
    _TRADINGDATASERVICE.methods_by_name["GetRiskFactors"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "GetRiskFactors"
    ]._serialized_options = b"\222A\t\n\007Markets"
    _TRADINGDATASERVICE.methods_by_name["ObserveEventBus"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ObserveEventBus"
    ]._serialized_options = b"\222A\010\n\006Events"
    _TRADINGDATASERVICE.methods_by_name["ObserveLedgerMovements"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ObserveLedgerMovements"
    ]._serialized_options = b"\222A\022\n\020Ledger movements"
    _TRADINGDATASERVICE.methods_by_name["ListKeyRotations"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListKeyRotations"
    ]._serialized_options = b"\222A\t\n\007Network"
    _TRADINGDATASERVICE.methods_by_name["ListEthereumKeyRotations"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListEthereumKeyRotations"
    ]._serialized_options = b"\222A\t\n\007Network"
    _TRADINGDATASERVICE.methods_by_name["GetVegaTime"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "GetVegaTime"
    ]._serialized_options = b"\222A\t\n\007Network"
    _TRADINGDATASERVICE.methods_by_name["GetProtocolUpgradeStatus"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "GetProtocolUpgradeStatus"
    ]._serialized_options = b"\222A\t\n\007Network"
    _TRADINGDATASERVICE.methods_by_name["ListProtocolUpgradeProposals"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListProtocolUpgradeProposals"
    ]._serialized_options = b"\222A\t\n\007Network"
    _TRADINGDATASERVICE.methods_by_name["ListCoreSnapshots"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListCoreSnapshots"
    ]._serialized_options = b"\222A\t\n\007Network"
    _TRADINGDATASERVICE.methods_by_name[
        "GetMostRecentNetworkHistorySegment"
    ]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "GetMostRecentNetworkHistorySegment"
    ]._serialized_options = b"\222A\021\n\017Network history"
    _TRADINGDATASERVICE.methods_by_name["ListAllNetworkHistorySegments"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListAllNetworkHistorySegments"
    ]._serialized_options = b"\222A\021\n\017Network history"
    _TRADINGDATASERVICE.methods_by_name[
        "GetActiveNetworkHistoryPeerAddresses"
    ]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "GetActiveNetworkHistoryPeerAddresses"
    ]._serialized_options = b"\222A\021\n\017Network history"
    _TRADINGDATASERVICE.methods_by_name["GetNetworkHistoryStatus"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "GetNetworkHistoryStatus"
    ]._serialized_options = b"\222A\021\n\017Network history"
    _TRADINGDATASERVICE.methods_by_name[
        "GetNetworkHistoryBootstrapPeers"
    ]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "GetNetworkHistoryBootstrapPeers"
    ]._serialized_options = b"\222A\021\n\017Network history"
    _TRADINGDATASERVICE.methods_by_name["ListEntities"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ListEntities"
    ]._serialized_options = b"\222A\n\n\010Explorer"
    _TRADINGDATASERVICE.methods_by_name["ExportNetworkHistory"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "ExportNetworkHistory"
    ]._serialized_options = b"\222A\021\n\017Network history"
    _TRADINGDATASERVICE.methods_by_name["Ping"]._options = None
    _TRADINGDATASERVICE.methods_by_name[
        "Ping"
    ]._serialized_options = b"\222A\006\n\004Misc"
    _globals["_LEDGERENTRYFIELD"]._serialized_start = 37359
    _globals["_LEDGERENTRYFIELD"]._serialized_end = 37529
    _globals["_ACCOUNTFIELD"]._serialized_start = 37532
    _globals["_ACCOUNTFIELD"]._serialized_end = 37708
    _globals["_TRANSFERDIRECTION"]._serialized_start = 37711
    _globals["_TRANSFERDIRECTION"]._serialized_end = 37884
    _globals["_TABLE"]._serialized_start = 37887
    _globals["_TABLE"]._serialized_end = 38237
    _globals["_PAGINATION"]._serialized_start = 335
    _globals["_PAGINATION"]._serialized_end = 552
    _globals["_PAGEINFO"]._serialized_start = 555
    _globals["_PAGEINFO"]._serialized_end = 711
    _globals["_ACCOUNTBALANCE"]._serialized_start = 714
    _globals["_ACCOUNTBALANCE"]._serialized_end = 868
    _globals["_LISTACCOUNTSREQUEST"]._serialized_start = 871
    _globals["_LISTACCOUNTSREQUEST"]._serialized_end = 1029
    _globals["_LISTACCOUNTSRESPONSE"]._serialized_start = 1031
    _globals["_LISTACCOUNTSRESPONSE"]._serialized_end = 1118
    _globals["_ACCOUNTSCONNECTION"]._serialized_start = 1121
    _globals["_ACCOUNTSCONNECTION"]._serialized_end = 1249
    _globals["_ACCOUNTEDGE"]._serialized_start = 1251
    _globals["_ACCOUNTEDGE"]._serialized_end = 1341
    _globals["_OBSERVEACCOUNTSREQUEST"]._serialized_start = 1344
    _globals["_OBSERVEACCOUNTSREQUEST"]._serialized_end = 1485
    _globals["_OBSERVEACCOUNTSRESPONSE"]._serialized_start = 1488
    _globals["_OBSERVEACCOUNTSRESPONSE"]._serialized_end = 1654
    _globals["_ACCOUNTSNAPSHOTPAGE"]._serialized_start = 1656
    _globals["_ACCOUNTSNAPSHOTPAGE"]._serialized_end = 1767
    _globals["_ACCOUNTUPDATES"]._serialized_start = 1769
    _globals["_ACCOUNTUPDATES"]._serialized_end = 1846
    _globals["_INFOREQUEST"]._serialized_start = 1848
    _globals["_INFOREQUEST"]._serialized_end = 1861
    _globals["_INFORESPONSE"]._serialized_start = 1863
    _globals["_INFORESPONSE"]._serialized_end = 1936
    _globals["_GETORDERREQUEST"]._serialized_start = 1938
    _globals["_GETORDERREQUEST"]._serialized_end = 2031
    _globals["_GETORDERRESPONSE"]._serialized_start = 2033
    _globals["_GETORDERRESPONSE"]._serialized_end = 2086
    _globals["_ORDERFILTER"]._serialized_start = 2089
    _globals["_ORDERFILTER"]._serialized_end = 2534
    _globals["_LISTORDERSREQUEST"]._serialized_start = 2537
    _globals["_LISTORDERSREQUEST"]._serialized_end = 2707
    _globals["_LISTORDERSRESPONSE"]._serialized_start = 2709
    _globals["_LISTORDERSRESPONSE"]._serialized_end = 2787
    _globals["_LISTORDERVERSIONSREQUEST"]._serialized_start = 2790
    _globals["_LISTORDERVERSIONSREQUEST"]._serialized_end = 2930
    _globals["_LISTORDERVERSIONSRESPONSE"]._serialized_start = 2932
    _globals["_LISTORDERVERSIONSRESPONSE"]._serialized_end = 3017
    _globals["_OBSERVEORDERSREQUEST"]._serialized_start = 3020
    _globals["_OBSERVEORDERSREQUEST"]._serialized_end = 3174
    _globals["_OBSERVEORDERSRESPONSE"]._serialized_start = 3177
    _globals["_OBSERVEORDERSRESPONSE"]._serialized_end = 3337
    _globals["_ORDERSNAPSHOTPAGE"]._serialized_start = 3339
    _globals["_ORDERSNAPSHOTPAGE"]._serialized_end = 3424
    _globals["_ORDERUPDATES"]._serialized_start = 3426
    _globals["_ORDERUPDATES"]._serialized_end = 3477
    _globals["_GETSTOPORDERREQUEST"]._serialized_start = 3479
    _globals["_GETSTOPORDERREQUEST"]._serialized_end = 3533
    _globals["_GETSTOPORDERRESPONSE"]._serialized_start = 3535
    _globals["_GETSTOPORDERRESPONSE"]._serialized_end = 3611
    _globals["_LISTSTOPORDERSREQUEST"]._serialized_start = 3614
    _globals["_LISTSTOPORDERSREQUEST"]._serialized_end = 3792
    _globals["_STOPORDERFILTER"]._serialized_start = 3795
    _globals["_STOPORDERFILTER"]._serialized_end = 4080
    _globals["_STOPORDEREDGE"]._serialized_start = 4082
    _globals["_STOPORDEREDGE"]._serialized_end = 4173
    _globals["_STOPORDERCONNECTION"]._serialized_start = 4176
    _globals["_STOPORDERCONNECTION"]._serialized_end = 4307
    _globals["_LISTSTOPORDERSRESPONSE"]._serialized_start = 4309
    _globals["_LISTSTOPORDERSRESPONSE"]._serialized_end = 4395
    _globals["_LISTPOSITIONSREQUEST"]._serialized_start = 4398
    _globals["_LISTPOSITIONSREQUEST"]._serialized_end = 4561
    _globals["_LISTPOSITIONSRESPONSE"]._serialized_start = 4563
    _globals["_LISTPOSITIONSRESPONSE"]._serialized_end = 4657
    _globals["_POSITIONSFILTER"]._serialized_start = 4659
    _globals["_POSITIONSFILTER"]._serialized_end = 4736
    _globals["_LISTALLPOSITIONSREQUEST"]._serialized_start = 4739
    _globals["_LISTALLPOSITIONSREQUEST"]._serialized_end = 4903
    _globals["_LISTALLPOSITIONSRESPONSE"]._serialized_start = 4905
    _globals["_LISTALLPOSITIONSRESPONSE"]._serialized_end = 4998
    _globals["_POSITIONEDGE"]._serialized_start = 5000
    _globals["_POSITIONEDGE"]._serialized_end = 5074
    _globals["_POSITIONCONNECTION"]._serialized_start = 5077
    _globals["_POSITIONCONNECTION"]._serialized_end = 5206
    _globals["_OBSERVEPOSITIONSREQUEST"]._serialized_start = 5208
    _globals["_OBSERVEPOSITIONSREQUEST"]._serialized_end = 5326
    _globals["_OBSERVEPOSITIONSRESPONSE"]._serialized_start = 5329
    _globals["_OBSERVEPOSITIONSRESPONSE"]._serialized_end = 5498
    _globals["_POSITIONSNAPSHOTPAGE"]._serialized_start = 5500
    _globals["_POSITIONSNAPSHOTPAGE"]._serialized_end = 5597
    _globals["_POSITIONUPDATES"]._serialized_start = 5599
    _globals["_POSITIONUPDATES"]._serialized_end = 5662
    _globals["_LEDGERENTRYFILTER"]._serialized_start = 5665
    _globals["_LEDGERENTRYFILTER"]._serialized_end = 5956
    _globals["_AGGREGATEDLEDGERENTRY"]._serialized_start = 5959
    _globals["_AGGREGATEDLEDGERENTRY"]._serialized_end = 6688
    _globals["_LISTLEDGERENTRIESREQUEST"]._serialized_start = 6691
    _globals["_LISTLEDGERENTRIESREQUEST"]._serialized_end = 6937
    _globals["_EXPORTLEDGERENTRIESREQUEST"]._serialized_start = 6940
    _globals["_EXPORTLEDGERENTRIESREQUEST"]._serialized_end = 7113
    _globals["_LISTLEDGERENTRIESRESPONSE"]._serialized_start = 7115
    _globals["_LISTLEDGERENTRIESRESPONSE"]._serialized_end = 7233
    _globals["_AGGREGATEDLEDGERENTRIESEDGE"]._serialized_start = 7235
    _globals["_AGGREGATEDLEDGERENTRIESEDGE"]._serialized_end = 7348
    _globals["_AGGREGATEDLEDGERENTRIESCONNECTION"]._serialized_start = 7351
    _globals["_AGGREGATEDLEDGERENTRIESCONNECTION"]._serialized_end = 7510
    _globals["_LISTBALANCECHANGESREQUEST"]._serialized_start = 7513
    _globals["_LISTBALANCECHANGESREQUEST"]._serialized_end = 7756
    _globals["_LISTBALANCECHANGESRESPONSE"]._serialized_start = 7758
    _globals["_LISTBALANCECHANGESRESPONSE"]._serialized_end = 7860
    _globals["_GETBALANCEHISTORYREQUEST"]._serialized_start = 7863
    _globals["_GETBALANCEHISTORYREQUEST"]._serialized_end = 8163
    _globals["_GETBALANCEHISTORYRESPONSE"]._serialized_start = 8165
    _globals["_GETBALANCEHISTORYRESPONSE"]._serialized_end = 8266
    _globals["_AGGREGATEDBALANCEEDGE"]._serialized_start = 8268
    _globals["_AGGREGATEDBALANCEEDGE"]._serialized_end = 8371
    _globals["_AGGREGATEDBALANCECONNECTION"]._serialized_start = 8374
    _globals["_AGGREGATEDBALANCECONNECTION"]._serialized_end = 8521
    _globals["_ACCOUNTFILTER"]._serialized_start = 8524
    _globals["_ACCOUNTFILTER"]._serialized_end = 8682
    _globals["_AGGREGATEDBALANCE"]._serialized_start = 8685
    _globals["_AGGREGATEDBALANCE"]._serialized_end = 8974
    _globals["_OBSERVEMARKETSDEPTHREQUEST"]._serialized_start = 8976
    _globals["_OBSERVEMARKETSDEPTHREQUEST"]._serialized_end = 9035
    _globals["_OBSERVEMARKETSDEPTHRESPONSE"]._serialized_start = 9037
    _globals["_OBSERVEMARKETSDEPTHRESPONSE"]._serialized_end = 9120
    _globals["_OBSERVEMARKETSDEPTHUPDATESREQUEST"]._serialized_start = 9122
    _globals["_OBSERVEMARKETSDEPTHUPDATESREQUEST"]._serialized_end = 9188
    _globals["_OBSERVEMARKETSDEPTHUPDATESRESPONSE"]._serialized_start = 9190
    _globals["_OBSERVEMARKETSDEPTHUPDATESRESPONSE"]._serialized_end = 9275
    _globals["_OBSERVEMARKETSDATAREQUEST"]._serialized_start = 9277
    _globals["_OBSERVEMARKETSDATAREQUEST"]._serialized_end = 9335
    _globals["_OBSERVEMARKETSDATARESPONSE"]._serialized_start = 9337
    _globals["_OBSERVEMARKETSDATARESPONSE"]._serialized_end = 9416
    _globals["_GETLATESTMARKETDEPTHREQUEST"]._serialized_start = 9418
    _globals["_GETLATESTMARKETDEPTHREQUEST"]._serialized_end = 9530
    _globals["_GETLATESTMARKETDEPTHRESPONSE"]._serialized_start = 9533
    _globals["_GETLATESTMARKETDEPTHRESPONSE"]._serialized_end = 9751
    _globals["_LISTLATESTMARKETDATAREQUEST"]._serialized_start = 9753
    _globals["_LISTLATESTMARKETDATAREQUEST"]._serialized_end = 9782
    _globals["_LISTLATESTMARKETDATARESPONSE"]._serialized_start = 9784
    _globals["_LISTLATESTMARKETDATARESPONSE"]._serialized_end = 9867
    _globals["_GETLATESTMARKETDATAREQUEST"]._serialized_start = 9869
    _globals["_GETLATESTMARKETDATAREQUEST"]._serialized_end = 9932
    _globals["_GETLATESTMARKETDATARESPONSE"]._serialized_start = 9934
    _globals["_GETLATESTMARKETDATARESPONSE"]._serialized_end = 10014
    _globals["_GETMARKETDATAHISTORYBYIDREQUEST"]._serialized_start = 10017
    _globals["_GETMARKETDATAHISTORYBYIDREQUEST"]._serialized_end = 10298
    _globals["_GETMARKETDATAHISTORYBYIDRESPONSE"]._serialized_start = 10300
    _globals["_GETMARKETDATAHISTORYBYIDRESPONSE"]._serialized_end = 10406
    _globals["_MARKETDATAEDGE"]._serialized_start = 10408
    _globals["_MARKETDATAEDGE"]._serialized_end = 10486
    _globals["_MARKETDATACONNECTION"]._serialized_start = 10489
    _globals["_MARKETDATACONNECTION"]._serialized_end = 10622
    _globals["_LISTTRANSFERSREQUEST"]._serialized_start = 10625
    _globals["_LISTTRANSFERSREQUEST"]._serialized_end = 10834
    _globals["_LISTTRANSFERSRESPONSE"]._serialized_start = 10836
    _globals["_LISTTRANSFERSRESPONSE"]._serialized_end = 10926
    _globals["_TRANSFEREDGE"]._serialized_start = 10928
    _globals["_TRANSFEREDGE"]._serialized_end = 11012
    _globals["_TRANSFERCONNECTION"]._serialized_start = 11015
    _globals["_TRANSFERCONNECTION"]._serialized_end = 11144
    _globals["_GETNETWORKLIMITSREQUEST"]._serialized_start = 11146
    _globals["_GETNETWORKLIMITSREQUEST"]._serialized_end = 11171
    _globals["_GETNETWORKLIMITSRESPONSE"]._serialized_start = 11173
    _globals["_GETNETWORKLIMITSRESPONSE"]._serialized_end = 11244
    _globals["_LISTCANDLEINTERVALSREQUEST"]._serialized_start = 11246
    _globals["_LISTCANDLEINTERVALSREQUEST"]._serialized_end = 11309
    _globals["_INTERVALTOCANDLEID"]._serialized_start = 11311
    _globals["_INTERVALTOCANDLEID"]._serialized_end = 11388
    _globals["_LISTCANDLEINTERVALSRESPONSE"]._serialized_start = 11390
    _globals["_LISTCANDLEINTERVALSRESPONSE"]._serialized_end = 11507
    _globals["_CANDLE"]._serialized_start = 11510
    _globals["_CANDLE"]._serialized_end = 11705
    _globals["_OBSERVECANDLEDATAREQUEST"]._serialized_start = 11707
    _globals["_OBSERVECANDLEDATAREQUEST"]._serialized_end = 11768
    _globals["_OBSERVECANDLEDATARESPONSE"]._serialized_start = 11770
    _globals["_OBSERVECANDLEDATARESPONSE"]._serialized_end = 11846
    _globals["_LISTCANDLEDATAREQUEST"]._serialized_start = 11849
    _globals["_LISTCANDLEDATAREQUEST"]._serialized_end = 12068
    _globals["_LISTCANDLEDATARESPONSE"]._serialized_start = 12070
    _globals["_LISTCANDLEDATARESPONSE"]._serialized_end = 12159
    _globals["_CANDLEEDGE"]._serialized_start = 12161
    _globals["_CANDLEEDGE"]._serialized_end = 12242
    _globals["_CANDLEDATACONNECTION"]._serialized_start = 12245
    _globals["_CANDLEDATACONNECTION"]._serialized_end = 12374
    _globals["_LISTVOTESREQUEST"]._serialized_start = 12377
    _globals["_LISTVOTESREQUEST"]._serialized_end = 12575
    _globals["_LISTVOTESRESPONSE"]._serialized_start = 12577
    _globals["_LISTVOTESRESPONSE"]._serialized_end = 12651
    _globals["_VOTEEDGE"]._serialized_start = 12653
    _globals["_VOTEEDGE"]._serialized_end = 12719
    _globals["_VOTECONNECTION"]._serialized_start = 12721
    _globals["_VOTECONNECTION"]._serialized_end = 12842
    _globals["_OBSERVEVOTESREQUEST"]._serialized_start = 12844
    _globals["_OBSERVEVOTESREQUEST"]._serialized_end = 12964
    _globals["_OBSERVEVOTESRESPONSE"]._serialized_start = 12966
    _globals["_OBSERVEVOTESRESPONSE"]._serialized_end = 13020
    _globals["_LISTERC20MULTISIGSIGNERADDEDBUNDLESREQUEST"]._serialized_start = 13023
    _globals["_LISTERC20MULTISIGSIGNERADDEDBUNDLESREQUEST"]._serialized_end = 13212
    _globals["_LISTERC20MULTISIGSIGNERADDEDBUNDLESRESPONSE"]._serialized_start = 13214
    _globals["_LISTERC20MULTISIGSIGNERADDEDBUNDLESRESPONSE"]._serialized_end = 13338
    _globals["_ERC20MULTISIGSIGNERADDEDEDGE"]._serialized_start = 13340
    _globals["_ERC20MULTISIGSIGNERADDEDEDGE"]._serialized_end = 13456
    _globals["_ERC20MULTISIGSIGNERADDEDBUNDLEEDGE"]._serialized_start = 13459
    _globals["_ERC20MULTISIGSIGNERADDEDBUNDLEEDGE"]._serialized_end = 13588
    _globals["_ERC20MULTISIGSIGNERADDEDCONNECTION"]._serialized_start = 13591
    _globals["_ERC20MULTISIGSIGNERADDEDCONNECTION"]._serialized_end = 13758
    _globals["_ERC20MULTISIGSIGNERADDEDBUNDLE"]._serialized_start = 13761
    _globals["_ERC20MULTISIGSIGNERADDEDBUNDLE"]._serialized_end = 13967
    _globals["_LISTERC20MULTISIGSIGNERREMOVEDBUNDLESREQUEST"]._serialized_start = 13970
    _globals["_LISTERC20MULTISIGSIGNERREMOVEDBUNDLESREQUEST"]._serialized_end = 14161
    _globals["_LISTERC20MULTISIGSIGNERREMOVEDBUNDLESRESPONSE"]._serialized_start = 14164
    _globals["_LISTERC20MULTISIGSIGNERREMOVEDBUNDLESRESPONSE"]._serialized_end = 14292
    _globals["_ERC20MULTISIGSIGNERREMOVEDEDGE"]._serialized_start = 14294
    _globals["_ERC20MULTISIGSIGNERREMOVEDEDGE"]._serialized_end = 14414
    _globals["_ERC20MULTISIGSIGNERREMOVEDBUNDLEEDGE"]._serialized_start = 14417
    _globals["_ERC20MULTISIGSIGNERREMOVEDBUNDLEEDGE"]._serialized_end = 14550
    _globals["_ERC20MULTISIGSIGNERREMOVEDCONNECTION"]._serialized_start = 14553
    _globals["_ERC20MULTISIGSIGNERREMOVEDCONNECTION"]._serialized_end = 14724
    _globals["_ERC20MULTISIGSIGNERREMOVEDBUNDLE"]._serialized_start = 14727
    _globals["_ERC20MULTISIGSIGNERREMOVEDBUNDLE"]._serialized_end = 14935
    _globals["_GETERC20LISTASSETBUNDLEREQUEST"]._serialized_start = 14937
    _globals["_GETERC20LISTASSETBUNDLEREQUEST"]._serialized_end = 15002
    _globals["_GETERC20LISTASSETBUNDLERESPONSE"]._serialized_start = 15005
    _globals["_GETERC20LISTASSETBUNDLERESPONSE"]._serialized_end = 15163
    _globals["_GETERC20SETASSETLIMITSBUNDLEREQUEST"]._serialized_start = 15165
    _globals["_GETERC20SETASSETLIMITSBUNDLEREQUEST"]._serialized_end = 15241
    _globals["_GETERC20SETASSETLIMITSBUNDLERESPONSE"]._serialized_start = 15244
    _globals["_GETERC20SETASSETLIMITSBUNDLERESPONSE"]._serialized_end = 15476
    _globals["_GETERC20WITHDRAWALAPPROVALREQUEST"]._serialized_start = 15478
    _globals["_GETERC20WITHDRAWALAPPROVALREQUEST"]._serialized_end = 15556
    _globals["_GETERC20WITHDRAWALAPPROVALRESPONSE"]._serialized_start = 15559
    _globals["_GETERC20WITHDRAWALAPPROVALRESPONSE"]._serialized_end = 15781
    _globals["_GETLASTTRADEREQUEST"]._serialized_start = 15783
    _globals["_GETLASTTRADEREQUEST"]._serialized_end = 15839
    _globals["_GETLASTTRADERESPONSE"]._serialized_start = 15841
    _globals["_GETLASTTRADERESPONSE"]._serialized_end = 15898
    _globals["_LISTTRADESREQUEST"]._serialized_start = 15901
    _globals["_LISTTRADESREQUEST"]._serialized_end = 16169
    _globals["_LISTTRADESRESPONSE"]._serialized_start = 16171
    _globals["_LISTTRADESRESPONSE"]._serialized_end = 16249
    _globals["_TRADECONNECTION"]._serialized_start = 16251
    _globals["_TRADECONNECTION"]._serialized_end = 16374
    _globals["_TRADEEDGE"]._serialized_start = 16376
    _globals["_TRADEEDGE"]._serialized_end = 16444
    _globals["_OBSERVETRADESREQUEST"]._serialized_start = 16446
    _globals["_OBSERVETRADESREQUEST"]._serialized_end = 16528
    _globals["_OBSERVETRADESRESPONSE"]._serialized_start = 16530
    _globals["_OBSERVETRADESRESPONSE"]._serialized_end = 16590
    _globals["_GETORACLESPECREQUEST"]._serialized_start = 16592
    _globals["_GETORACLESPECREQUEST"]._serialized_end = 16658
    _globals["_GETORACLESPECRESPONSE"]._serialized_start = 16660
    _globals["_GETORACLESPECRESPONSE"]._serialized_end = 16734
    _globals["_LISTORACLESPECSREQUEST"]._serialized_start = 16736
    _globals["_LISTORACLESPECSREQUEST"]._serialized_end = 16841
    _globals["_LISTORACLESPECSRESPONSE"]._serialized_start = 16843
    _globals["_LISTORACLESPECSRESPONSE"]._serialized_end = 16943
    _globals["_LISTORACLEDATAREQUEST"]._serialized_start = 16946
    _globals["_LISTORACLEDATAREQUEST"]._serialized_end = 17112
    _globals["_LISTORACLEDATARESPONSE"]._serialized_start = 17114
    _globals["_LISTORACLEDATARESPONSE"]._serialized_end = 17210
    _globals["_ORACLESPECEDGE"]._serialized_start = 17212
    _globals["_ORACLESPECEDGE"]._serialized_end = 17290
    _globals["_ORACLESPECSCONNECTION"]._serialized_start = 17293
    _globals["_ORACLESPECSCONNECTION"]._serialized_end = 17427
    _globals["_ORACLEDATAEDGE"]._serialized_start = 17429
    _globals["_ORACLEDATAEDGE"]._serialized_end = 17507
    _globals["_ORACLEDATACONNECTION"]._serialized_start = 17510
    _globals["_ORACLEDATACONNECTION"]._serialized_end = 17643
    _globals["_GETMARKETREQUEST"]._serialized_start = 17645
    _globals["_GETMARKETREQUEST"]._serialized_end = 17698
    _globals["_GETMARKETRESPONSE"]._serialized_start = 17700
    _globals["_GETMARKETRESPONSE"]._serialized_end = 17757
    _globals["_LISTMARKETSREQUEST"]._serialized_start = 17760
    _globals["_LISTMARKETSREQUEST"]._serialized_end = 17927
    _globals["_LISTMARKETSRESPONSE"]._serialized_start = 17929
    _globals["_LISTMARKETSRESPONSE"]._serialized_end = 18011
    _globals["_MARKETEDGE"]._serialized_start = 18013
    _globals["_MARKETEDGE"]._serialized_end = 18083
    _globals["_MARKETCONNECTION"]._serialized_start = 18085
    _globals["_MARKETCONNECTION"]._serialized_end = 18210
    _globals["_LISTSUCCESSORMARKETSREQUEST"]._serialized_start = 18213
    _globals["_LISTSUCCESSORMARKETSREQUEST"]._serialized_end = 18388
    _globals["_SUCCESSORMARKET"]._serialized_start = 18390
    _globals["_SUCCESSORMARKET"]._serialized_end = 18497
    _globals["_SUCCESSORMARKETEDGE"]._serialized_start = 18499
    _globals["_SUCCESSORMARKETEDGE"]._serialized_end = 18598
    _globals["_SUCCESSORMARKETCONNECTION"]._serialized_start = 18601
    _globals["_SUCCESSORMARKETCONNECTION"]._serialized_end = 18744
    _globals["_LISTSUCCESSORMARKETSRESPONSE"]._serialized_start = 18746
    _globals["_LISTSUCCESSORMARKETSRESPONSE"]._serialized_end = 18865
    _globals["_GETPARTYREQUEST"]._serialized_start = 18867
    _globals["_GETPARTYREQUEST"]._serialized_end = 18917
    _globals["_GETPARTYRESPONSE"]._serialized_start = 18919
    _globals["_GETPARTYRESPONSE"]._serialized_end = 18972
    _globals["_LISTPARTIESREQUEST"]._serialized_start = 18974
    _globals["_LISTPARTIESREQUEST"]._serialized_end = 19082
    _globals["_LISTPARTIESRESPONSE"]._serialized_start = 19084
    _globals["_LISTPARTIESRESPONSE"]._serialized_end = 19165
    _globals["_PARTYEDGE"]._serialized_start = 19167
    _globals["_PARTYEDGE"]._serialized_end = 19235
    _globals["_PARTYCONNECTION"]._serialized_start = 19237
    _globals["_PARTYCONNECTION"]._serialized_end = 19360
    _globals["_ORDEREDGE"]._serialized_start = 19362
    _globals["_ORDEREDGE"]._serialized_end = 19430
    _globals["_LISTMARGINLEVELSREQUEST"]._serialized_start = 19433
    _globals["_LISTMARGINLEVELSREQUEST"]._serialized_end = 19575
    _globals["_LISTMARGINLEVELSRESPONSE"]._serialized_start = 19577
    _globals["_LISTMARGINLEVELSRESPONSE"]._serialized_end = 19675
    _globals["_OBSERVEMARGINLEVELSREQUEST"]._serialized_start = 19677
    _globals["_OBSERVEMARGINLEVELSREQUEST"]._serialized_end = 19780
    _globals["_OBSERVEMARGINLEVELSRESPONSE"]._serialized_start = 19782
    _globals["_OBSERVEMARGINLEVELSRESPONSE"]._serialized_end = 19868
    _globals["_ORDERCONNECTION"]._serialized_start = 19870
    _globals["_ORDERCONNECTION"]._serialized_end = 19993
    _globals["_MARGINEDGE"]._serialized_start = 19995
    _globals["_MARGINEDGE"]._serialized_end = 20071
    _globals["_MARGINCONNECTION"]._serialized_start = 20073
    _globals["_MARGINCONNECTION"]._serialized_end = 20198
    _globals["_LISTREWARDSREQUEST"]._serialized_start = 20201
    _globals["_LISTREWARDSREQUEST"]._serialized_end = 20470
    _globals["_LISTREWARDSRESPONSE"]._serialized_start = 20472
    _globals["_LISTREWARDSRESPONSE"]._serialized_end = 20555
    _globals["_REWARDEDGE"]._serialized_start = 20557
    _globals["_REWARDEDGE"]._serialized_end = 20627
    _globals["_REWARDSCONNECTION"]._serialized_start = 20629
    _globals["_REWARDSCONNECTION"]._serialized_end = 20755
    _globals["_LISTREWARDSUMMARIESREQUEST"]._serialized_start = 20758
    _globals["_LISTREWARDSUMMARIESREQUEST"]._serialized_end = 20957
    _globals["_LISTREWARDSUMMARIESRESPONSE"]._serialized_start = 20959
    _globals["_LISTREWARDSUMMARIESRESPONSE"]._serialized_end = 21039
    _globals["_REWARDSUMMARYFILTER"]._serialized_start = 21042
    _globals["_REWARDSUMMARYFILTER"]._serialized_end = 21219
    _globals["_LISTEPOCHREWARDSUMMARIESREQUEST"]._serialized_start = 21222
    _globals["_LISTEPOCHREWARDSUMMARIESREQUEST"]._serialized_end = 21398
    _globals["_LISTEPOCHREWARDSUMMARIESRESPONSE"]._serialized_start = 21400
    _globals["_LISTEPOCHREWARDSUMMARIESRESPONSE"]._serialized_end = 21511
    _globals["_EPOCHREWARDSUMMARYCONNECTION"]._serialized_start = 21514
    _globals["_EPOCHREWARDSUMMARYCONNECTION"]._serialized_end = 21663
    _globals["_EPOCHREWARDSUMMARYEDGE"]._serialized_start = 21665
    _globals["_EPOCHREWARDSUMMARYEDGE"]._serialized_end = 21759
    _globals["_OBSERVEREWARDSREQUEST"]._serialized_start = 21761
    _globals["_OBSERVEREWARDSREQUEST"]._serialized_end = 21874
    _globals["_OBSERVEREWARDSRESPONSE"]._serialized_start = 21876
    _globals["_OBSERVEREWARDSRESPONSE"]._serialized_end = 21938
    _globals["_GETDEPOSITREQUEST"]._serialized_start = 21940
    _globals["_GETDEPOSITREQUEST"]._serialized_end = 21981
    _globals["_GETDEPOSITRESPONSE"]._serialized_start = 21983
    _globals["_GETDEPOSITRESPONSE"]._serialized_end = 22044
    _globals["_LISTDEPOSITSREQUEST"]._serialized_start = 22047
    _globals["_LISTDEPOSITSREQUEST"]._serialized_end = 22255
    _globals["_LISTDEPOSITSRESPONSE"]._serialized_start = 22257
    _globals["_LISTDEPOSITSRESPONSE"]._serialized_end = 22344
    _globals["_DEPOSITEDGE"]._serialized_start = 22346
    _globals["_DEPOSITEDGE"]._serialized_end = 22418
    _globals["_DEPOSITSCONNECTION"]._serialized_start = 22421
    _globals["_DEPOSITSCONNECTION"]._serialized_end = 22549
    _globals["_GETWITHDRAWALREQUEST"]._serialized_start = 22551
    _globals["_GETWITHDRAWALREQUEST"]._serialized_end = 22595
    _globals["_GETWITHDRAWALRESPONSE"]._serialized_start = 22597
    _globals["_GETWITHDRAWALRESPONSE"]._serialized_end = 22670
    _globals["_LISTWITHDRAWALSREQUEST"]._serialized_start = 22673
    _globals["_LISTWITHDRAWALSREQUEST"]._serialized_end = 22884
    _globals["_LISTWITHDRAWALSRESPONSE"]._serialized_start = 22886
    _globals["_LISTWITHDRAWALSRESPONSE"]._serialized_end = 22985
    _globals["_WITHDRAWALEDGE"]._serialized_start = 22987
    _globals["_WITHDRAWALEDGE"]._serialized_end = 23065
    _globals["_WITHDRAWALSCONNECTION"]._serialized_start = 23068
    _globals["_WITHDRAWALSCONNECTION"]._serialized_end = 23202
    _globals["_GETASSETREQUEST"]._serialized_start = 23204
    _globals["_GETASSETREQUEST"]._serialized_end = 23254
    _globals["_GETASSETRESPONSE"]._serialized_start = 23256
    _globals["_GETASSETRESPONSE"]._serialized_end = 23309
    _globals["_LISTASSETSREQUEST"]._serialized_start = 23312
    _globals["_LISTASSETSREQUEST"]._serialized_end = 23457
    _globals["_LISTASSETSRESPONSE"]._serialized_start = 23459
    _globals["_LISTASSETSRESPONSE"]._serialized_end = 23538
    _globals["_ASSETEDGE"]._serialized_start = 23540
    _globals["_ASSETEDGE"]._serialized_end = 23608
    _globals["_ASSETSCONNECTION"]._serialized_start = 23610
    _globals["_ASSETSCONNECTION"]._serialized_end = 23734
    _globals["_LISTLIQUIDITYPROVISIONSREQUEST"]._serialized_start = 23737
    _globals["_LISTLIQUIDITYPROVISIONSREQUEST"]._serialized_end = 24026
    _globals["_LISTLIQUIDITYPROVISIONSRESPONSE"]._serialized_start = 24029
    _globals["_LISTLIQUIDITYPROVISIONSRESPONSE"]._serialized_end = 24161
    _globals["_LIQUIDITYPROVISIONSEDGE"]._serialized_start = 24163
    _globals["_LIQUIDITYPROVISIONSEDGE"]._serialized_end = 24258
    _globals["_LIQUIDITYPROVISIONSCONNECTION"]._serialized_start = 24261
    _globals["_LIQUIDITYPROVISIONSCONNECTION"]._serialized_end = 24412
    _globals["_OBSERVELIQUIDITYPROVISIONSREQUEST"]._serialized_start = 24415
    _globals["_OBSERVELIQUIDITYPROVISIONSREQUEST"]._serialized_end = 24543
    _globals["_OBSERVELIQUIDITYPROVISIONSRESPONSE"]._serialized_start = 24545
    _globals["_OBSERVELIQUIDITYPROVISIONSRESPONSE"]._serialized_end = 24658
    _globals["_GETGOVERNANCEDATAREQUEST"]._serialized_start = 24661
    _globals["_GETGOVERNANCEDATAREQUEST"]._serialized_end = 24790
    _globals["_GETGOVERNANCEDATARESPONSE"]._serialized_start = 24792
    _globals["_GETGOVERNANCEDATARESPONSE"]._serialized_end = 24861
    _globals["_LISTGOVERNANCEDATAREQUEST"]._serialized_start = 24864
    _globals["_LISTGOVERNANCEDATAREQUEST"]._serialized_end = 25498
    _globals["_LISTGOVERNANCEDATAREQUEST_TYPE"]._serialized_start = 25218
    _globals["_LISTGOVERNANCEDATAREQUEST_TYPE"]._serialized_end = 25401
    _globals["_LISTGOVERNANCEDATARESPONSE"]._serialized_start = 25500
    _globals["_LISTGOVERNANCEDATARESPONSE"]._serialized_end = 25603
    _globals["_GOVERNANCEDATAEDGE"]._serialized_start = 25605
    _globals["_GOVERNANCEDATAEDGE"]._serialized_end = 25691
    _globals["_GOVERNANCEDATACONNECTION"]._serialized_start = 25694
    _globals["_GOVERNANCEDATACONNECTION"]._serialized_end = 25835
    _globals["_OBSERVEGOVERNANCEREQUEST"]._serialized_start = 25837
    _globals["_OBSERVEGOVERNANCEREQUEST"]._serialized_end = 25908
    _globals["_OBSERVEGOVERNANCERESPONSE"]._serialized_start = 25910
    _globals["_OBSERVEGOVERNANCERESPONSE"]._serialized_end = 25979
    _globals["_LISTDELEGATIONSREQUEST"]._serialized_start = 25982
    _globals["_LISTDELEGATIONSREQUEST"]._serialized_end = 26219
    _globals["_LISTDELEGATIONSRESPONSE"]._serialized_start = 26221
    _globals["_LISTDELEGATIONSRESPONSE"]._serialized_end = 26320
    _globals["_DELEGATIONEDGE"]._serialized_start = 26322
    _globals["_DELEGATIONEDGE"]._serialized_end = 26400
    _globals["_DELEGATIONSCONNECTION"]._serialized_start = 26403
    _globals["_DELEGATIONSCONNECTION"]._serialized_end = 26537
    _globals["_OBSERVEDELEGATIONSREQUEST"]._serialized_start = 26539
    _globals["_OBSERVEDELEGATIONSREQUEST"]._serialized_end = 26653
    _globals["_OBSERVEDELEGATIONSRESPONSE"]._serialized_start = 26655
    _globals["_OBSERVEDELEGATIONSRESPONSE"]._serialized_end = 26733
    _globals["_NODEBASIC"]._serialized_start = 26736
    _globals["_NODEBASIC"]._serialized_end = 27009
    _globals["_GETNETWORKDATAREQUEST"]._serialized_start = 27011
    _globals["_GETNETWORKDATAREQUEST"]._serialized_end = 27034
    _globals["_GETNETWORKDATARESPONSE"]._serialized_start = 27036
    _globals["_GETNETWORKDATARESPONSE"]._serialized_end = 27105
    _globals["_GETNODEREQUEST"]._serialized_start = 27107
    _globals["_GETNODEREQUEST"]._serialized_end = 27145
    _globals["_GETNODERESPONSE"]._serialized_start = 27147
    _globals["_GETNODERESPONSE"]._serialized_end = 27196
    _globals["_LISTNODESREQUEST"]._serialized_start = 27199
    _globals["_LISTNODESREQUEST"]._serialized_end = 27346
    _globals["_LISTNODESRESPONSE"]._serialized_start = 27348
    _globals["_LISTNODESRESPONSE"]._serialized_end = 27423
    _globals["_NODEEDGE"]._serialized_start = 27425
    _globals["_NODEEDGE"]._serialized_end = 27491
    _globals["_NODESCONNECTION"]._serialized_start = 27493
    _globals["_NODESCONNECTION"]._serialized_end = 27615
    _globals["_LISTNODESIGNATURESREQUEST"]._serialized_start = 27618
    _globals["_LISTNODESIGNATURESREQUEST"]._serialized_end = 27748
    _globals["_LISTNODESIGNATURESRESPONSE"]._serialized_start = 27750
    _globals["_LISTNODESIGNATURESRESPONSE"]._serialized_end = 27853
    _globals["_NODESIGNATUREEDGE"]._serialized_start = 27855
    _globals["_NODESIGNATUREEDGE"]._serialized_end = 27951
    _globals["_NODESIGNATURESCONNECTION"]._serialized_start = 27954
    _globals["_NODESIGNATURESCONNECTION"]._serialized_end = 28094
    _globals["_GETEPOCHREQUEST"]._serialized_start = 28096
    _globals["_GETEPOCHREQUEST"]._serialized_end = 28178
    _globals["_GETEPOCHRESPONSE"]._serialized_start = 28180
    _globals["_GETEPOCHRESPONSE"]._serialized_end = 28233
    _globals["_ESTIMATEFEEREQUEST"]._serialized_start = 28235
    _globals["_ESTIMATEFEEREQUEST"]._serialized_end = 28344
    _globals["_ESTIMATEFEERESPONSE"]._serialized_start = 28346
    _globals["_ESTIMATEFEERESPONSE"]._serialized_end = 28396
    _globals["_ESTIMATEMARGINREQUEST"]._serialized_start = 28399
    _globals["_ESTIMATEMARGINREQUEST"]._serialized_end = 28630
    _globals["_ESTIMATEMARGINRESPONSE"]._serialized_start = 28632
    _globals["_ESTIMATEMARGINRESPONSE"]._serialized_end = 28717
    _globals["_LISTNETWORKPARAMETERSREQUEST"]._serialized_start = 28719
    _globals["_LISTNETWORKPARAMETERSREQUEST"]._serialized_end = 28830
    _globals["_LISTNETWORKPARAMETERSRESPONSE"]._serialized_start = 28832
    _globals["_LISTNETWORKPARAMETERSRESPONSE"]._serialized_end = 28955
    _globals["_GETNETWORKPARAMETERREQUEST"]._serialized_start = 28957
    _globals["_GETNETWORKPARAMETERREQUEST"]._serialized_end = 29009
    _globals["_GETNETWORKPARAMETERRESPONSE"]._serialized_start = 29011
    _globals["_GETNETWORKPARAMETERRESPONSE"]._serialized_end = 29109
    _globals["_NETWORKPARAMETEREDGE"]._serialized_start = 29111
    _globals["_NETWORKPARAMETEREDGE"]._serialized_end = 29201
    _globals["_NETWORKPARAMETERCONNECTION"]._serialized_start = 29204
    _globals["_NETWORKPARAMETERCONNECTION"]._serialized_end = 29349
    _globals["_CHECKPOINT"]._serialized_start = 29351
    _globals["_CHECKPOINT"]._serialized_end = 29441
    _globals["_LISTCHECKPOINTSREQUEST"]._serialized_start = 29443
    _globals["_LISTCHECKPOINTSREQUEST"]._serialized_end = 29548
    _globals["_LISTCHECKPOINTSRESPONSE"]._serialized_start = 29550
    _globals["_LISTCHECKPOINTSRESPONSE"]._serialized_end = 29649
    _globals["_CHECKPOINTEDGE"]._serialized_start = 29651
    _globals["_CHECKPOINTEDGE"]._serialized_end = 29740
    _globals["_CHECKPOINTSCONNECTION"]._serialized_start = 29743
    _globals["_CHECKPOINTSCONNECTION"]._serialized_end = 29877
    _globals["_GETSTAKEREQUEST"]._serialized_start = 29880
    _globals["_GETSTAKEREQUEST"]._serialized_end = 30011
    _globals["_GETSTAKERESPONSE"]._serialized_start = 30014
    _globals["_GETSTAKERESPONSE"]._serialized_end = 30162
    _globals["_STAKELINKINGEDGE"]._serialized_start = 30164
    _globals["_STAKELINKINGEDGE"]._serialized_end = 30256
    _globals["_STAKESCONNECTION"]._serialized_start = 30259
    _globals["_STAKESCONNECTION"]._serialized_end = 30390
    _globals["_GETRISKFACTORSREQUEST"]._serialized_start = 30392
    _globals["_GETRISKFACTORSREQUEST"]._serialized_end = 30450
    _globals["_GETRISKFACTORSRESPONSE"]._serialized_start = 30452
    _globals["_GETRISKFACTORSRESPONSE"]._serialized_end = 30527
    _globals["_OBSERVEEVENTBUSREQUEST"]._serialized_start = 30530
    _globals["_OBSERVEEVENTBUSREQUEST"]._serialized_end = 30691
    _globals["_OBSERVEEVENTBUSRESPONSE"]._serialized_start = 30693
    _globals["_OBSERVEEVENTBUSRESPONSE"]._serialized_end = 30768
    _globals["_OBSERVELEDGERMOVEMENTSREQUEST"]._serialized_start = 30770
    _globals["_OBSERVELEDGERMOVEMENTSREQUEST"]._serialized_end = 30801
    _globals["_OBSERVELEDGERMOVEMENTSRESPONSE"]._serialized_start = 30803
    _globals["_OBSERVELEDGERMOVEMENTSRESPONSE"]._serialized_end = 30898
    _globals["_LISTKEYROTATIONSREQUEST"]._serialized_start = 30901
    _globals["_LISTKEYROTATIONSREQUEST"]._serialized_end = 31049
    _globals["_LISTKEYROTATIONSRESPONSE"]._serialized_start = 31051
    _globals["_LISTKEYROTATIONSRESPONSE"]._serialized_end = 31147
    _globals["_KEYROTATIONEDGE"]._serialized_start = 31149
    _globals["_KEYROTATIONEDGE"]._serialized_end = 31239
    _globals["_KEYROTATIONCONNECTION"]._serialized_start = 31242
    _globals["_KEYROTATIONCONNECTION"]._serialized_end = 31377
    _globals["_LISTETHEREUMKEYROTATIONSREQUEST"]._serialized_start = 31380
    _globals["_LISTETHEREUMKEYROTATIONSREQUEST"]._serialized_end = 31536
    _globals["_LISTETHEREUMKEYROTATIONSRESPONSE"]._serialized_start = 31538
    _globals["_LISTETHEREUMKEYROTATIONSRESPONSE"]._serialized_end = 31658
    _globals["_ETHEREUMKEYROTATIONSCONNECTION"]._serialized_start = 31661
    _globals["_ETHEREUMKEYROTATIONSCONNECTION"]._serialized_end = 31813
    _globals["_ETHEREUMKEYROTATIONEDGE"]._serialized_start = 31815
    _globals["_ETHEREUMKEYROTATIONEDGE"]._serialized_end = 31921
    _globals["_GETVEGATIMEREQUEST"]._serialized_start = 31923
    _globals["_GETVEGATIMEREQUEST"]._serialized_end = 31943
    _globals["_GETVEGATIMERESPONSE"]._serialized_start = 31945
    _globals["_GETVEGATIMERESPONSE"]._serialized_end = 31996
    _globals["_DATERANGE"]._serialized_start = 31999
    _globals["_DATERANGE"]._serialized_end = 32136
    _globals["_GETPROTOCOLUPGRADESTATUSREQUEST"]._serialized_start = 32138
    _globals["_GETPROTOCOLUPGRADESTATUSREQUEST"]._serialized_end = 32171
    _globals["_GETPROTOCOLUPGRADESTATUSRESPONSE"]._serialized_start = 32173
    _globals["_GETPROTOCOLUPGRADESTATUSRESPONSE"]._serialized_end = 32229
    _globals["_LISTPROTOCOLUPGRADEPROPOSALSREQUEST"]._serialized_start = 32232
    _globals["_LISTPROTOCOLUPGRADEPROPOSALSREQUEST"]._serialized_end = 32491
    _globals["_LISTPROTOCOLUPGRADEPROPOSALSRESPONSE"]._serialized_start = 32494
    _globals["_LISTPROTOCOLUPGRADEPROPOSALSRESPONSE"]._serialized_end = 32646
    _globals["_PROTOCOLUPGRADEPROPOSALCONNECTION"]._serialized_start = 32649
    _globals["_PROTOCOLUPGRADEPROPOSALCONNECTION"]._serialized_end = 32808
    _globals["_PROTOCOLUPGRADEPROPOSALEDGE"]._serialized_start = 32810
    _globals["_PROTOCOLUPGRADEPROPOSALEDGE"]._serialized_end = 32921
    _globals["_LISTCORESNAPSHOTSREQUEST"]._serialized_start = 32923
    _globals["_LISTCORESNAPSHOTSREQUEST"]._serialized_end = 33030
    _globals["_LISTCORESNAPSHOTSRESPONSE"]._serialized_start = 33032
    _globals["_LISTCORESNAPSHOTSRESPONSE"]._serialized_end = 33139
    _globals["_CORESNAPSHOTCONNECTION"]._serialized_start = 33142
    _globals["_CORESNAPSHOTCONNECTION"]._serialized_end = 33279
    _globals["_CORESNAPSHOTEDGE"]._serialized_start = 33281
    _globals["_CORESNAPSHOTEDGE"]._serialized_end = 33377
    _globals["_HISTORYSEGMENT"]._serialized_start = 33380
    _globals["_HISTORYSEGMENT"]._serialized_end = 33637
    _globals["_GETMOSTRECENTNETWORKHISTORYSEGMENTREQUEST"]._serialized_start = 33639
    _globals["_GETMOSTRECENTNETWORKHISTORYSEGMENTREQUEST"]._serialized_end = 33682
    _globals["_GETMOSTRECENTNETWORKHISTORYSEGMENTRESPONSE"]._serialized_start = 33685
    _globals["_GETMOSTRECENTNETWORKHISTORYSEGMENTRESPONSE"]._serialized_end = 33826
    _globals["_LISTALLNETWORKHISTORYSEGMENTSREQUEST"]._serialized_start = 33828
    _globals["_LISTALLNETWORKHISTORYSEGMENTSREQUEST"]._serialized_end = 33866
    _globals["_LISTALLNETWORKHISTORYSEGMENTSRESPONSE"]._serialized_start = 33868
    _globals["_LISTALLNETWORKHISTORYSEGMENTSRESPONSE"]._serialized_end = 33968
    _globals["_GETACTIVENETWORKHISTORYPEERADDRESSESREQUEST"]._serialized_start = 33970
    _globals["_GETACTIVENETWORKHISTORYPEERADDRESSESREQUEST"]._serialized_end = 34015
    _globals["_GETACTIVENETWORKHISTORYPEERADDRESSESRESPONSE"]._serialized_start = 34017
    _globals["_GETACTIVENETWORKHISTORYPEERADDRESSESRESPONSE"]._serialized_end = 34098
    _globals["_GETNETWORKHISTORYSTATUSREQUEST"]._serialized_start = 34100
    _globals["_GETNETWORKHISTORYSTATUSREQUEST"]._serialized_end = 34132
    _globals["_GETNETWORKHISTORYSTATUSRESPONSE"]._serialized_start = 34135
    _globals["_GETNETWORKHISTORYSTATUSRESPONSE"]._serialized_end = 34311
    _globals["_GETNETWORKHISTORYBOOTSTRAPPEERSREQUEST"]._serialized_start = 34313
    _globals["_GETNETWORKHISTORYBOOTSTRAPPEERSREQUEST"]._serialized_end = 34353
    _globals["_GETNETWORKHISTORYBOOTSTRAPPEERSRESPONSE"]._serialized_start = 34355
    _globals["_GETNETWORKHISTORYBOOTSTRAPPEERSRESPONSE"]._serialized_end = 34437
    _globals["_EXPORTNETWORKHISTORYREQUEST"]._serialized_start = 34440
    _globals["_EXPORTNETWORKHISTORYREQUEST"]._serialized_end = 34573
    _globals["_LISTENTITIESREQUEST"]._serialized_start = 34575
    _globals["_LISTENTITIESREQUEST"]._serialized_end = 34645
    _globals["_LISTENTITIESRESPONSE"]._serialized_start = 34648
    _globals["_LISTENTITIESRESPONSE"]._serialized_end = 36357
    _globals["_PINGREQUEST"]._serialized_start = 36359
    _globals["_PINGREQUEST"]._serialized_end = 36372
    _globals["_PINGRESPONSE"]._serialized_start = 36374
    _globals["_PINGRESPONSE"]._serialized_end = 36388
    _globals["_ORDERINFO"]._serialized_start = 36391
    _globals["_ORDERINFO"]._serialized_end = 36526
    _globals["_ESTIMATEPOSITIONREQUEST"]._serialized_start = 36529
    _globals["_ESTIMATEPOSITIONREQUEST"]._serialized_end = 36761
    _globals["_ESTIMATEPOSITIONRESPONSE"]._serialized_start = 36764
    _globals["_ESTIMATEPOSITIONRESPONSE"]._serialized_end = 36919
    _globals["_MARGINESTIMATE"]._serialized_start = 36921
    _globals["_MARGINESTIMATE"]._serialized_end = 37037
    _globals["_LIQUIDATIONESTIMATE"]._serialized_start = 37040
    _globals["_LIQUIDATIONESTIMATE"]._serialized_end = 37191
    _globals["_LIQUIDATIONPRICE"]._serialized_start = 37194
    _globals["_LIQUIDATIONPRICE"]._serialized_end = 37356
    _globals["_TRADINGDATASERVICE"]._serialized_start = 38240
    _globals["_TRADINGDATASERVICE"]._serialized_end = 49490
# @@protoc_insertion_point(module_scope)
